import java.awt
import java.awt.geom
import java.io
import java.lang
import java.text
import java.util
import typing



class FontRenderContext:
    @typing.overload
    def __init__(self, affineTransform: java.awt.geom.AffineTransform, boolean: bool, boolean2: bool): ...
    @typing.overload
    def __init__(self, affineTransform: java.awt.geom.AffineTransform, object: typing.Any, object2: typing.Any): ...
    @typing.overload
    def equals(self, fontRenderContext: 'FontRenderContext') -> bool: ...
    @typing.overload
    def equals(self, object: typing.Any) -> bool: ...
    def getAntiAliasingHint(self) -> typing.Any: ...
    def getFractionalMetricsHint(self) -> typing.Any: ...
    def getTransform(self) -> java.awt.geom.AffineTransform: ...
    def getTransformType(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAntiAliased(self) -> bool: ...
    def isTransformed(self) -> bool: ...
    def usesFractionalMetrics(self) -> bool: ...

class GlyphJustificationInfo:
    PRIORITY_KASHIDA: typing.ClassVar[int] = ...
    PRIORITY_WHITESPACE: typing.ClassVar[int] = ...
    PRIORITY_INTERCHAR: typing.ClassVar[int] = ...
    PRIORITY_NONE: typing.ClassVar[int] = ...
    weight: float = ...
    growPriority: int = ...
    growAbsorb: bool = ...
    growLeftLimit: float = ...
    growRightLimit: float = ...
    shrinkPriority: int = ...
    shrinkAbsorb: bool = ...
    shrinkLeftLimit: float = ...
    shrinkRightLimit: float = ...
    def __init__(self, float: float, boolean: bool, int: int, float2: float, float3: float, boolean2: bool, int2: int, float4: float, float5: float): ...

class GlyphMetrics:
    STANDARD: typing.ClassVar[int] = ...
    LIGATURE: typing.ClassVar[int] = ...
    COMBINING: typing.ClassVar[int] = ...
    COMPONENT: typing.ClassVar[int] = ...
    WHITESPACE: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, boolean: bool, float: float, float2: float, rectangle2D: java.awt.geom.Rectangle2D, byte: int): ...
    @typing.overload
    def __init__(self, float: float, rectangle2D: java.awt.geom.Rectangle2D, byte: int): ...
    def getAdvance(self) -> float: ...
    def getAdvanceX(self) -> float: ...
    def getAdvanceY(self) -> float: ...
    def getBounds2D(self) -> java.awt.geom.Rectangle2D: ...
    def getLSB(self) -> float: ...
    def getRSB(self) -> float: ...
    def getType(self) -> int: ...
    def isCombining(self) -> bool: ...
    def isComponent(self) -> bool: ...
    def isLigature(self) -> bool: ...
    def isStandard(self) -> bool: ...
    def isWhitespace(self) -> bool: ...

class GlyphVector(java.lang.Cloneable):
    FLAG_HAS_TRANSFORMS: typing.ClassVar[int] = ...
    FLAG_HAS_POSITION_ADJUSTMENTS: typing.ClassVar[int] = ...
    FLAG_RUN_RTL: typing.ClassVar[int] = ...
    FLAG_COMPLEX_GLYPHS: typing.ClassVar[int] = ...
    FLAG_MASK: typing.ClassVar[int] = ...
    def __init__(self): ...
    @typing.overload
    def equals(self, glyphVector: 'GlyphVector') -> bool: ...
    @typing.overload
    def equals(self, object: typing.Any) -> bool: ...
    def getFont(self) -> java.awt.Font: ...
    def getFontRenderContext(self) -> FontRenderContext: ...
    def getGlyphCharIndex(self, int: int) -> int: ...
    def getGlyphCharIndices(self, int: int, int2: int, intArray: typing.List[int]) -> typing.List[int]: ...
    def getGlyphCode(self, int: int) -> int: ...
    def getGlyphCodes(self, int: int, int2: int, intArray: typing.List[int]) -> typing.List[int]: ...
    def getGlyphJustificationInfo(self, int: int) -> GlyphJustificationInfo: ...
    def getGlyphLogicalBounds(self, int: int) -> java.awt.Shape: ...
    def getGlyphMetrics(self, int: int) -> GlyphMetrics: ...
    @typing.overload
    def getGlyphOutline(self, int: int) -> java.awt.Shape: ...
    @typing.overload
    def getGlyphOutline(self, int: int, float: float, float2: float) -> java.awt.Shape: ...
    def getGlyphPixelBounds(self, int: int, fontRenderContext: FontRenderContext, float: float, float2: float) -> java.awt.Rectangle: ...
    def getGlyphPosition(self, int: int) -> java.awt.geom.Point2D: ...
    def getGlyphPositions(self, int: int, int2: int, floatArray: typing.List[float]) -> typing.List[float]: ...
    def getGlyphTransform(self, int: int) -> java.awt.geom.AffineTransform: ...
    def getGlyphVisualBounds(self, int: int) -> java.awt.Shape: ...
    def getLayoutFlags(self) -> int: ...
    def getLogicalBounds(self) -> java.awt.geom.Rectangle2D: ...
    def getNumGlyphs(self) -> int: ...
    @typing.overload
    def getOutline(self) -> java.awt.Shape: ...
    @typing.overload
    def getOutline(self, float: float, float2: float) -> java.awt.Shape: ...
    def getPixelBounds(self, fontRenderContext: FontRenderContext, float: float, float2: float) -> java.awt.Rectangle: ...
    def getVisualBounds(self) -> java.awt.geom.Rectangle2D: ...
    def performDefaultLayout(self) -> None: ...
    def setGlyphPosition(self, int: int, point2D: java.awt.geom.Point2D) -> None: ...
    def setGlyphTransform(self, int: int, affineTransform: java.awt.geom.AffineTransform) -> None: ...

class GraphicAttribute:
    TOP_ALIGNMENT: typing.ClassVar[int] = ...
    BOTTOM_ALIGNMENT: typing.ClassVar[int] = ...
    ROMAN_BASELINE: typing.ClassVar[int] = ...
    CENTER_BASELINE: typing.ClassVar[int] = ...
    HANGING_BASELINE: typing.ClassVar[int] = ...
    def draw(self, graphics2D: java.awt.Graphics2D, float: float, float2: float) -> None: ...
    def getAdvance(self) -> float: ...
    def getAlignment(self) -> int: ...
    def getAscent(self) -> float: ...
    def getBounds(self) -> java.awt.geom.Rectangle2D: ...
    def getDescent(self) -> float: ...
    def getJustificationInfo(self) -> GlyphJustificationInfo: ...
    def getOutline(self, affineTransform: java.awt.geom.AffineTransform) -> java.awt.Shape: ...

class LayoutPath:
    def __init__(self): ...
    def pathToPoint(self, point2D: java.awt.geom.Point2D, boolean: bool, point2D2: java.awt.geom.Point2D) -> None: ...
    def pointToPath(self, point2D: java.awt.geom.Point2D, point2D2: java.awt.geom.Point2D) -> bool: ...

class LineBreakMeasurer:
    @typing.overload
    def __init__(self, attributedCharacterIterator: java.text.AttributedCharacterIterator, fontRenderContext: FontRenderContext): ...
    @typing.overload
    def __init__(self, attributedCharacterIterator: java.text.AttributedCharacterIterator, breakIterator: java.text.BreakIterator, fontRenderContext: FontRenderContext): ...
    def deleteChar(self, attributedCharacterIterator: java.text.AttributedCharacterIterator, int: int) -> None: ...
    def getPosition(self) -> int: ...
    def insertChar(self, attributedCharacterIterator: java.text.AttributedCharacterIterator, int: int) -> None: ...
    @typing.overload
    def nextLayout(self, float: float) -> 'TextLayout': ...
    @typing.overload
    def nextLayout(self, float: float, int: int, boolean: bool) -> 'TextLayout': ...
    @typing.overload
    def nextOffset(self, float: float) -> int: ...
    @typing.overload
    def nextOffset(self, float: float, int: int, boolean: bool) -> int: ...
    def setPosition(self, int: int) -> None: ...

class LineMetrics:
    def __init__(self): ...
    def getAscent(self) -> float: ...
    def getBaselineIndex(self) -> int: ...
    def getBaselineOffsets(self) -> typing.List[float]: ...
    def getDescent(self) -> float: ...
    def getHeight(self) -> float: ...
    def getLeading(self) -> float: ...
    def getNumChars(self) -> int: ...
    def getStrikethroughOffset(self) -> float: ...
    def getStrikethroughThickness(self) -> float: ...
    def getUnderlineOffset(self) -> float: ...
    def getUnderlineThickness(self) -> float: ...

class MultipleMaster:
    @typing.overload
    def deriveMMFont(self, floatArray: typing.List[float]) -> java.awt.Font: ...
    @typing.overload
    def deriveMMFont(self, floatArray: typing.List[float], float2: float, float3: float, float4: float, float5: float) -> java.awt.Font: ...
    def getDesignAxisDefaults(self) -> typing.List[float]: ...
    def getDesignAxisNames(self) -> typing.List[str]: ...
    def getDesignAxisRanges(self) -> typing.List[float]: ...
    def getNumDesignAxes(self) -> int: ...

class NumericShaper(java.io.Serializable):
    EUROPEAN: typing.ClassVar[int] = ...
    ARABIC: typing.ClassVar[int] = ...
    EASTERN_ARABIC: typing.ClassVar[int] = ...
    DEVANAGARI: typing.ClassVar[int] = ...
    BENGALI: typing.ClassVar[int] = ...
    GURMUKHI: typing.ClassVar[int] = ...
    GUJARATI: typing.ClassVar[int] = ...
    ORIYA: typing.ClassVar[int] = ...
    TAMIL: typing.ClassVar[int] = ...
    TELUGU: typing.ClassVar[int] = ...
    KANNADA: typing.ClassVar[int] = ...
    MALAYALAM: typing.ClassVar[int] = ...
    THAI: typing.ClassVar[int] = ...
    LAO: typing.ClassVar[int] = ...
    TIBETAN: typing.ClassVar[int] = ...
    MYANMAR: typing.ClassVar[int] = ...
    ETHIOPIC: typing.ClassVar[int] = ...
    KHMER: typing.ClassVar[int] = ...
    MONGOLIAN: typing.ClassVar[int] = ...
    ALL_RANGES: typing.ClassVar[int] = ...
    def equals(self, object: typing.Any) -> bool: ...
    @typing.overload
    @staticmethod
    def getContextualShaper(int: int) -> 'NumericShaper': ...
    @typing.overload
    @staticmethod
    def getContextualShaper(int: int, int2: int) -> 'NumericShaper': ...
    @typing.overload
    @staticmethod
    def getContextualShaper(set: java.util.Set['NumericShaper.Range']) -> 'NumericShaper': ...
    @typing.overload
    @staticmethod
    def getContextualShaper(set: java.util.Set['NumericShaper.Range'], range: 'NumericShaper.Range') -> 'NumericShaper': ...
    def getRangeSet(self) -> java.util.Set['NumericShaper.Range']: ...
    def getRanges(self) -> int: ...
    @typing.overload
    @staticmethod
    def getShaper(int: int) -> 'NumericShaper': ...
    @typing.overload
    @staticmethod
    def getShaper(range: 'NumericShaper.Range') -> 'NumericShaper': ...
    def hashCode(self) -> int: ...
    def isContextual(self) -> bool: ...
    @typing.overload
    def shape(self, charArray: typing.List[str], int: int, int2: int) -> None: ...
    @typing.overload
    def shape(self, charArray: typing.List[str], int: int, int2: int, int3: int) -> None: ...
    @typing.overload
    def shape(self, charArray: typing.List[str], int: int, int2: int, range: 'NumericShaper.Range') -> None: ...
    def toString(self) -> str: ...
    class Range(java.lang.Enum['NumericShaper.Range']):
        EUROPEAN: typing.ClassVar['NumericShaper.Range'] = ...
        ARABIC: typing.ClassVar['NumericShaper.Range'] = ...
        EASTERN_ARABIC: typing.ClassVar['NumericShaper.Range'] = ...
        DEVANAGARI: typing.ClassVar['NumericShaper.Range'] = ...
        BENGALI: typing.ClassVar['NumericShaper.Range'] = ...
        GURMUKHI: typing.ClassVar['NumericShaper.Range'] = ...
        GUJARATI: typing.ClassVar['NumericShaper.Range'] = ...
        ORIYA: typing.ClassVar['NumericShaper.Range'] = ...
        TAMIL: typing.ClassVar['NumericShaper.Range'] = ...
        TELUGU: typing.ClassVar['NumericShaper.Range'] = ...
        KANNADA: typing.ClassVar['NumericShaper.Range'] = ...
        MALAYALAM: typing.ClassVar['NumericShaper.Range'] = ...
        THAI: typing.ClassVar['NumericShaper.Range'] = ...
        LAO: typing.ClassVar['NumericShaper.Range'] = ...
        TIBETAN: typing.ClassVar['NumericShaper.Range'] = ...
        MYANMAR: typing.ClassVar['NumericShaper.Range'] = ...
        ETHIOPIC: typing.ClassVar['NumericShaper.Range'] = ...
        KHMER: typing.ClassVar['NumericShaper.Range'] = ...
        MONGOLIAN: typing.ClassVar['NumericShaper.Range'] = ...
        NKO: typing.ClassVar['NumericShaper.Range'] = ...
        MYANMAR_SHAN: typing.ClassVar['NumericShaper.Range'] = ...
        LIMBU: typing.ClassVar['NumericShaper.Range'] = ...
        NEW_TAI_LUE: typing.ClassVar['NumericShaper.Range'] = ...
        BALINESE: typing.ClassVar['NumericShaper.Range'] = ...
        SUNDANESE: typing.ClassVar['NumericShaper.Range'] = ...
        LEPCHA: typing.ClassVar['NumericShaper.Range'] = ...
        OL_CHIKI: typing.ClassVar['NumericShaper.Range'] = ...
        VAI: typing.ClassVar['NumericShaper.Range'] = ...
        SAURASHTRA: typing.ClassVar['NumericShaper.Range'] = ...
        KAYAH_LI: typing.ClassVar['NumericShaper.Range'] = ...
        CHAM: typing.ClassVar['NumericShaper.Range'] = ...
        TAI_THAM_HORA: typing.ClassVar['NumericShaper.Range'] = ...
        TAI_THAM_THAM: typing.ClassVar['NumericShaper.Range'] = ...
        JAVANESE: typing.ClassVar['NumericShaper.Range'] = ...
        MEETEI_MAYEK: typing.ClassVar['NumericShaper.Range'] = ...
        SINHALA: typing.ClassVar['NumericShaper.Range'] = ...
        MYANMAR_TAI_LAING: typing.ClassVar['NumericShaper.Range'] = ...
        _valueOf_1__T = typing.TypeVar('_valueOf_1__T', bound=java.lang.Enum)  # <T>
        @typing.overload
        @staticmethod
        def valueOf(string: str) -> 'NumericShaper.Range': ...
        @typing.overload
        @staticmethod
        def valueOf(class_: typing.Type[_valueOf_1__T], string: str) -> _valueOf_1__T: ...
        @staticmethod
        def values() -> typing.List['NumericShaper.Range']: ...

class OpenType:
    TAG_CMAP: typing.ClassVar[int] = ...
    TAG_HEAD: typing.ClassVar[int] = ...
    TAG_NAME: typing.ClassVar[int] = ...
    TAG_GLYF: typing.ClassVar[int] = ...
    TAG_MAXP: typing.ClassVar[int] = ...
    TAG_PREP: typing.ClassVar[int] = ...
    TAG_HMTX: typing.ClassVar[int] = ...
    TAG_KERN: typing.ClassVar[int] = ...
    TAG_HDMX: typing.ClassVar[int] = ...
    TAG_LOCA: typing.ClassVar[int] = ...
    TAG_POST: typing.ClassVar[int] = ...
    TAG_OS2: typing.ClassVar[int] = ...
    TAG_CVT: typing.ClassVar[int] = ...
    TAG_GASP: typing.ClassVar[int] = ...
    TAG_VDMX: typing.ClassVar[int] = ...
    TAG_VMTX: typing.ClassVar[int] = ...
    TAG_VHEA: typing.ClassVar[int] = ...
    TAG_HHEA: typing.ClassVar[int] = ...
    TAG_TYP1: typing.ClassVar[int] = ...
    TAG_BSLN: typing.ClassVar[int] = ...
    TAG_GSUB: typing.ClassVar[int] = ...
    TAG_DSIG: typing.ClassVar[int] = ...
    TAG_FPGM: typing.ClassVar[int] = ...
    TAG_FVAR: typing.ClassVar[int] = ...
    TAG_GVAR: typing.ClassVar[int] = ...
    TAG_CFF: typing.ClassVar[int] = ...
    TAG_MMSD: typing.ClassVar[int] = ...
    TAG_MMFX: typing.ClassVar[int] = ...
    TAG_BASE: typing.ClassVar[int] = ...
    TAG_GDEF: typing.ClassVar[int] = ...
    TAG_GPOS: typing.ClassVar[int] = ...
    TAG_JSTF: typing.ClassVar[int] = ...
    TAG_EBDT: typing.ClassVar[int] = ...
    TAG_EBLC: typing.ClassVar[int] = ...
    TAG_EBSC: typing.ClassVar[int] = ...
    TAG_LTSH: typing.ClassVar[int] = ...
    TAG_PCLT: typing.ClassVar[int] = ...
    TAG_ACNT: typing.ClassVar[int] = ...
    TAG_AVAR: typing.ClassVar[int] = ...
    TAG_BDAT: typing.ClassVar[int] = ...
    TAG_BLOC: typing.ClassVar[int] = ...
    TAG_CVAR: typing.ClassVar[int] = ...
    TAG_FEAT: typing.ClassVar[int] = ...
    TAG_FDSC: typing.ClassVar[int] = ...
    TAG_FMTX: typing.ClassVar[int] = ...
    TAG_JUST: typing.ClassVar[int] = ...
    TAG_LCAR: typing.ClassVar[int] = ...
    TAG_MORT: typing.ClassVar[int] = ...
    TAG_OPBD: typing.ClassVar[int] = ...
    TAG_PROP: typing.ClassVar[int] = ...
    TAG_TRAK: typing.ClassVar[int] = ...
    @typing.overload
    def getFontTable(self, int: int) -> typing.List[int]: ...
    @typing.overload
    def getFontTable(self, int: int, int2: int, int3: int) -> typing.List[int]: ...
    @typing.overload
    def getFontTable(self, string: str) -> typing.List[int]: ...
    @typing.overload
    def getFontTable(self, string: str, int: int, int2: int) -> typing.List[int]: ...
    @typing.overload
    def getFontTableSize(self, int: int) -> int: ...
    @typing.overload
    def getFontTableSize(self, string: str) -> int: ...
    def getVersion(self) -> int: ...

class TextAttribute(java.text.AttributedCharacterIterator.Attribute):
    FAMILY: typing.ClassVar['TextAttribute'] = ...
    WEIGHT: typing.ClassVar['TextAttribute'] = ...
    WEIGHT_EXTRA_LIGHT: typing.ClassVar[float] = ...
    WEIGHT_LIGHT: typing.ClassVar[float] = ...
    WEIGHT_DEMILIGHT: typing.ClassVar[float] = ...
    WEIGHT_REGULAR: typing.ClassVar[float] = ...
    WEIGHT_SEMIBOLD: typing.ClassVar[float] = ...
    WEIGHT_MEDIUM: typing.ClassVar[float] = ...
    WEIGHT_DEMIBOLD: typing.ClassVar[float] = ...
    WEIGHT_BOLD: typing.ClassVar[float] = ...
    WEIGHT_HEAVY: typing.ClassVar[float] = ...
    WEIGHT_EXTRABOLD: typing.ClassVar[float] = ...
    WEIGHT_ULTRABOLD: typing.ClassVar[float] = ...
    WIDTH: typing.ClassVar['TextAttribute'] = ...
    WIDTH_CONDENSED: typing.ClassVar[float] = ...
    WIDTH_SEMI_CONDENSED: typing.ClassVar[float] = ...
    WIDTH_REGULAR: typing.ClassVar[float] = ...
    WIDTH_SEMI_EXTENDED: typing.ClassVar[float] = ...
    WIDTH_EXTENDED: typing.ClassVar[float] = ...
    POSTURE: typing.ClassVar['TextAttribute'] = ...
    POSTURE_REGULAR: typing.ClassVar[float] = ...
    POSTURE_OBLIQUE: typing.ClassVar[float] = ...
    SIZE: typing.ClassVar['TextAttribute'] = ...
    TRANSFORM: typing.ClassVar['TextAttribute'] = ...
    SUPERSCRIPT: typing.ClassVar['TextAttribute'] = ...
    SUPERSCRIPT_SUPER: typing.ClassVar[int] = ...
    SUPERSCRIPT_SUB: typing.ClassVar[int] = ...
    FONT: typing.ClassVar['TextAttribute'] = ...
    CHAR_REPLACEMENT: typing.ClassVar['TextAttribute'] = ...
    FOREGROUND: typing.ClassVar['TextAttribute'] = ...
    BACKGROUND: typing.ClassVar['TextAttribute'] = ...
    UNDERLINE: typing.ClassVar['TextAttribute'] = ...
    UNDERLINE_ON: typing.ClassVar[int] = ...
    STRIKETHROUGH: typing.ClassVar['TextAttribute'] = ...
    STRIKETHROUGH_ON: typing.ClassVar[bool] = ...
    RUN_DIRECTION: typing.ClassVar['TextAttribute'] = ...
    RUN_DIRECTION_LTR: typing.ClassVar[bool] = ...
    RUN_DIRECTION_RTL: typing.ClassVar[bool] = ...
    BIDI_EMBEDDING: typing.ClassVar['TextAttribute'] = ...
    JUSTIFICATION: typing.ClassVar['TextAttribute'] = ...
    JUSTIFICATION_FULL: typing.ClassVar[float] = ...
    JUSTIFICATION_NONE: typing.ClassVar[float] = ...
    INPUT_METHOD_HIGHLIGHT: typing.ClassVar['TextAttribute'] = ...
    INPUT_METHOD_UNDERLINE: typing.ClassVar['TextAttribute'] = ...
    UNDERLINE_LOW_ONE_PIXEL: typing.ClassVar[int] = ...
    UNDERLINE_LOW_TWO_PIXEL: typing.ClassVar[int] = ...
    UNDERLINE_LOW_DOTTED: typing.ClassVar[int] = ...
    UNDERLINE_LOW_GRAY: typing.ClassVar[int] = ...
    UNDERLINE_LOW_DASHED: typing.ClassVar[int] = ...
    SWAP_COLORS: typing.ClassVar['TextAttribute'] = ...
    SWAP_COLORS_ON: typing.ClassVar[bool] = ...
    NUMERIC_SHAPING: typing.ClassVar['TextAttribute'] = ...
    KERNING: typing.ClassVar['TextAttribute'] = ...
    KERNING_ON: typing.ClassVar[int] = ...
    LIGATURES: typing.ClassVar['TextAttribute'] = ...
    LIGATURES_ON: typing.ClassVar[int] = ...
    TRACKING: typing.ClassVar['TextAttribute'] = ...
    TRACKING_TIGHT: typing.ClassVar[float] = ...
    TRACKING_LOOSE: typing.ClassVar[float] = ...

class TextHitInfo:
    @staticmethod
    def afterOffset(int: int) -> 'TextHitInfo': ...
    @staticmethod
    def beforeOffset(int: int) -> 'TextHitInfo': ...
    @typing.overload
    def equals(self, textHitInfo: 'TextHitInfo') -> bool: ...
    @typing.overload
    def equals(self, object: typing.Any) -> bool: ...
    def getCharIndex(self) -> int: ...
    def getInsertionIndex(self) -> int: ...
    def getOffsetHit(self, int: int) -> 'TextHitInfo': ...
    def getOtherHit(self) -> 'TextHitInfo': ...
    def hashCode(self) -> int: ...
    def isLeadingEdge(self) -> bool: ...
    @staticmethod
    def leading(int: int) -> 'TextHitInfo': ...
    def toString(self) -> str: ...
    @staticmethod
    def trailing(int: int) -> 'TextHitInfo': ...

class TextLayout(java.lang.Cloneable):
    DEFAULT_CARET_POLICY: typing.ClassVar['TextLayout.CaretPolicy'] = ...
    @typing.overload
    def __init__(self, string: str, font: java.awt.Font, fontRenderContext: FontRenderContext): ...
    @typing.overload
    def __init__(self, string: str, map: typing.Union[java.util.Map[java.text.AttributedCharacterIterator.Attribute, typing.Any], typing.Mapping[java.text.AttributedCharacterIterator.Attribute, typing.Any]], fontRenderContext: FontRenderContext): ...
    @typing.overload
    def __init__(self, attributedCharacterIterator: java.text.AttributedCharacterIterator, fontRenderContext: FontRenderContext): ...
    def draw(self, graphics2D: java.awt.Graphics2D, float: float, float2: float) -> None: ...
    @typing.overload
    def equals(self, textLayout: 'TextLayout') -> bool: ...
    @typing.overload
    def equals(self, object: typing.Any) -> bool: ...
    def getAdvance(self) -> float: ...
    def getAscent(self) -> float: ...
    def getBaseline(self) -> int: ...
    def getBaselineOffsets(self) -> typing.List[float]: ...
    def getBlackBoxBounds(self, int: int, int2: int) -> java.awt.Shape: ...
    def getBounds(self) -> java.awt.geom.Rectangle2D: ...
    @typing.overload
    def getCaretInfo(self, textHitInfo: TextHitInfo) -> typing.List[float]: ...
    @typing.overload
    def getCaretInfo(self, textHitInfo: TextHitInfo, rectangle2D: java.awt.geom.Rectangle2D) -> typing.List[float]: ...
    @typing.overload
    def getCaretShape(self, textHitInfo: TextHitInfo) -> java.awt.Shape: ...
    @typing.overload
    def getCaretShape(self, textHitInfo: TextHitInfo, rectangle2D: java.awt.geom.Rectangle2D) -> java.awt.Shape: ...
    @typing.overload
    def getCaretShapes(self, int: int) -> typing.List[java.awt.Shape]: ...
    @typing.overload
    def getCaretShapes(self, int: int, rectangle2D: java.awt.geom.Rectangle2D) -> typing.List[java.awt.Shape]: ...
    @typing.overload
    def getCaretShapes(self, int: int, rectangle2D: java.awt.geom.Rectangle2D, caretPolicy: 'TextLayout.CaretPolicy') -> typing.List[java.awt.Shape]: ...
    def getCharacterCount(self) -> int: ...
    def getCharacterLevel(self, int: int) -> int: ...
    def getDescent(self) -> float: ...
    def getJustifiedLayout(self, float: float) -> 'TextLayout': ...
    def getLayoutPath(self) -> LayoutPath: ...
    def getLeading(self) -> float: ...
    @typing.overload
    def getLogicalHighlightShape(self, int: int, int2: int) -> java.awt.Shape: ...
    @typing.overload
    def getLogicalHighlightShape(self, int: int, int2: int, rectangle2D: java.awt.geom.Rectangle2D) -> java.awt.Shape: ...
    def getLogicalRangesForVisualSelection(self, textHitInfo: TextHitInfo, textHitInfo2: TextHitInfo) -> typing.List[int]: ...
    @typing.overload
    def getNextLeftHit(self, int: int) -> TextHitInfo: ...
    @typing.overload
    def getNextLeftHit(self, int: int, caretPolicy: 'TextLayout.CaretPolicy') -> TextHitInfo: ...
    @typing.overload
    def getNextLeftHit(self, textHitInfo: TextHitInfo) -> TextHitInfo: ...
    @typing.overload
    def getNextRightHit(self, int: int) -> TextHitInfo: ...
    @typing.overload
    def getNextRightHit(self, int: int, caretPolicy: 'TextLayout.CaretPolicy') -> TextHitInfo: ...
    @typing.overload
    def getNextRightHit(self, textHitInfo: TextHitInfo) -> TextHitInfo: ...
    def getOutline(self, affineTransform: java.awt.geom.AffineTransform) -> java.awt.Shape: ...
    def getPixelBounds(self, fontRenderContext: FontRenderContext, float: float, float2: float) -> java.awt.Rectangle: ...
    def getVisibleAdvance(self) -> float: ...
    @typing.overload
    def getVisualHighlightShape(self, textHitInfo: TextHitInfo, textHitInfo2: TextHitInfo) -> java.awt.Shape: ...
    @typing.overload
    def getVisualHighlightShape(self, textHitInfo: TextHitInfo, textHitInfo2: TextHitInfo, rectangle2D: java.awt.geom.Rectangle2D) -> java.awt.Shape: ...
    def getVisualOtherHit(self, textHitInfo: TextHitInfo) -> TextHitInfo: ...
    @typing.overload
    def hitTestChar(self, float: float, float2: float) -> TextHitInfo: ...
    @typing.overload
    def hitTestChar(self, float: float, float2: float, rectangle2D: java.awt.geom.Rectangle2D) -> TextHitInfo: ...
    def hitToPoint(self, textHitInfo: TextHitInfo, point2D: java.awt.geom.Point2D) -> None: ...
    def isLeftToRight(self) -> bool: ...
    def isVertical(self) -> bool: ...
    def toString(self) -> str: ...
    class CaretPolicy:
        def __init__(self): ...
        def getStrongCaret(self, textHitInfo: TextHitInfo, textHitInfo2: TextHitInfo, textLayout: 'TextLayout') -> TextHitInfo: ...

class TextMeasurer(java.lang.Cloneable):
    def __init__(self, attributedCharacterIterator: java.text.AttributedCharacterIterator, fontRenderContext: FontRenderContext): ...
    def deleteChar(self, attributedCharacterIterator: java.text.AttributedCharacterIterator, int: int) -> None: ...
    def getAdvanceBetween(self, int: int, int2: int) -> float: ...
    def getLayout(self, int: int, int2: int) -> TextLayout: ...
    def getLineBreakIndex(self, int: int, float: float) -> int: ...
    def insertChar(self, attributedCharacterIterator: java.text.AttributedCharacterIterator, int: int) -> None: ...

class TransformAttribute(java.io.Serializable):
    IDENTITY: typing.ClassVar['TransformAttribute'] = ...
    def __init__(self, affineTransform: java.awt.geom.AffineTransform): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getTransform(self) -> java.awt.geom.AffineTransform: ...
    def hashCode(self) -> int: ...
    def isIdentity(self) -> bool: ...

class ImageGraphicAttribute(GraphicAttribute):
    @typing.overload
    def __init__(self, image: java.awt.Image, int: int): ...
    @typing.overload
    def __init__(self, image: java.awt.Image, int: int, float: float, float2: float): ...
    def draw(self, graphics2D: java.awt.Graphics2D, float: float, float2: float) -> None: ...
    @typing.overload
    def equals(self, imageGraphicAttribute: 'ImageGraphicAttribute') -> bool: ...
    @typing.overload
    def equals(self, object: typing.Any) -> bool: ...
    def getAdvance(self) -> float: ...
    def getAscent(self) -> float: ...
    def getBounds(self) -> java.awt.geom.Rectangle2D: ...
    def getDescent(self) -> float: ...
    def hashCode(self) -> int: ...

class ShapeGraphicAttribute(GraphicAttribute):
    STROKE: typing.ClassVar[bool] = ...
    FILL: typing.ClassVar[bool] = ...
    def __init__(self, shape: java.awt.Shape, int: int, boolean: bool): ...
    def draw(self, graphics2D: java.awt.Graphics2D, float: float, float2: float) -> None: ...
    @typing.overload
    def equals(self, shapeGraphicAttribute: 'ShapeGraphicAttribute') -> bool: ...
    @typing.overload
    def equals(self, object: typing.Any) -> bool: ...
    def getAdvance(self) -> float: ...
    def getAscent(self) -> float: ...
    def getBounds(self) -> java.awt.geom.Rectangle2D: ...
    def getDescent(self) -> float: ...
    def getOutline(self, affineTransform: java.awt.geom.AffineTransform) -> java.awt.Shape: ...
    def hashCode(self) -> int: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.awt.font")``.

    FontRenderContext: typing.Type[FontRenderContext]
    GlyphJustificationInfo: typing.Type[GlyphJustificationInfo]
    GlyphMetrics: typing.Type[GlyphMetrics]
    GlyphVector: typing.Type[GlyphVector]
    GraphicAttribute: typing.Type[GraphicAttribute]
    ImageGraphicAttribute: typing.Type[ImageGraphicAttribute]
    LayoutPath: typing.Type[LayoutPath]
    LineBreakMeasurer: typing.Type[LineBreakMeasurer]
    LineMetrics: typing.Type[LineMetrics]
    MultipleMaster: typing.Type[MultipleMaster]
    NumericShaper: typing.Type[NumericShaper]
    OpenType: typing.Type[OpenType]
    ShapeGraphicAttribute: typing.Type[ShapeGraphicAttribute]
    TextAttribute: typing.Type[TextAttribute]
    TextHitInfo: typing.Type[TextHitInfo]
    TextLayout: typing.Type[TextLayout]
    TextMeasurer: typing.Type[TextMeasurer]
    TransformAttribute: typing.Type[TransformAttribute]



import java.awt
import java.awt.datatransfer
import java.awt.dnd
import typing



class DragSourceContextPeer:
    def getCursor(self) -> java.awt.Cursor: ...
    def setCursor(self, cursor: java.awt.Cursor) -> None: ...
    def startDrag(self, dragSourceContext: java.awt.dnd.DragSourceContext, cursor: java.awt.Cursor, image: java.awt.Image, point: java.awt.Point) -> None: ...
    def transferablesFlavorsChanged(self) -> None: ...

class DropTargetContextPeer:
    def acceptDrag(self, int: int) -> None: ...
    def acceptDrop(self, int: int) -> None: ...
    def dropComplete(self, boolean: bool) -> None: ...
    def getDropTarget(self) -> java.awt.dnd.DropTarget: ...
    def getTargetActions(self) -> int: ...
    def getTransferDataFlavors(self) -> typing.List[java.awt.datatransfer.DataFlavor]: ...
    def getTransferable(self) -> java.awt.datatransfer.Transferable: ...
    def isTransferableJVMLocal(self) -> bool: ...
    def rejectDrag(self) -> None: ...
    def rejectDrop(self) -> None: ...
    def setTargetActions(self, int: int) -> None: ...

class DropTargetPeer:
    def addDropTarget(self, dropTarget: java.awt.dnd.DropTarget) -> None: ...
    def removeDropTarget(self, dropTarget: java.awt.dnd.DropTarget) -> None: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.awt.dnd.peer")``.

    DragSourceContextPeer: typing.Type[DragSourceContextPeer]
    DropTargetContextPeer: typing.Type[DropTargetContextPeer]
    DropTargetPeer: typing.Type[DropTargetPeer]



import scala.collection
import typing



class ArithUtils:
    @typing.overload
    @staticmethod
    def addExact(a: int, b: int) -> int: ...
    @typing.overload
    @staticmethod
    def addExact(a: int, b: int, c: scala.collection.Seq[typing.Any]) -> int: ...
    @staticmethod
    def multiplyExact(e1: int, e2: int) -> int: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.utils")``.

    ArithUtils: typing.Type[ArithUtils]



import java.lang
import java.security
import java.util
import typing



class AclEntry(java.lang.Cloneable):
    def addPermission(self, permission: 'Permission') -> bool: ...
    def checkPermission(self, permission: 'Permission') -> bool: ...
    def clone(self) -> typing.Any: ...
    def getPrincipal(self) -> java.security.Principal: ...
    def isNegative(self) -> bool: ...
    def permissions(self) -> java.util.Enumeration['Permission']: ...
    def removePermission(self, permission: 'Permission') -> bool: ...
    def setNegativePermissions(self) -> None: ...
    def setPrincipal(self, principal: java.security.Principal) -> bool: ...
    def toString(self) -> str: ...

class AclNotFoundException(java.lang.Exception):
    def __init__(self): ...

class Group(java.security.Principal):
    def addMember(self, principal: java.security.Principal) -> bool: ...
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def isMember(self, principal: java.security.Principal) -> bool: ...
    def members(self) -> java.util.Enumeration[java.security.Principal]: ...
    def removeMember(self, principal: java.security.Principal) -> bool: ...
    def toString(self) -> str: ...

class LastOwnerException(java.lang.Exception):
    def __init__(self): ...

class NotOwnerException(java.lang.Exception):
    def __init__(self): ...

class Owner:
    def addOwner(self, principal: java.security.Principal, principal2: java.security.Principal) -> bool: ...
    def deleteOwner(self, principal: java.security.Principal, principal2: java.security.Principal) -> bool: ...
    def isOwner(self, principal: java.security.Principal) -> bool: ...

class Permission:
    def equals(self, object: typing.Any) -> bool: ...
    def toString(self) -> str: ...

class Acl(Owner):
    def addEntry(self, principal: java.security.Principal, aclEntry: AclEntry) -> bool: ...
    def checkPermission(self, principal: java.security.Principal, permission: Permission) -> bool: ...
    def entries(self) -> java.util.Enumeration[AclEntry]: ...
    def getName(self) -> str: ...
    def getPermissions(self, principal: java.security.Principal) -> java.util.Enumeration[Permission]: ...
    def removeEntry(self, principal: java.security.Principal, aclEntry: AclEntry) -> bool: ...
    def setName(self, principal: java.security.Principal, string: str) -> None: ...
    def toString(self) -> str: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.security.acl")``.

    Acl: typing.Type[Acl]
    AclEntry: typing.Type[AclEntry]
    AclNotFoundException: typing.Type[AclNotFoundException]
    Group: typing.Type[Group]
    LastOwnerException: typing.Type[LastOwnerException]
    NotOwnerException: typing.Type[NotOwnerException]
    Owner: typing.Type[Owner]
    Permission: typing.Type[Permission]



import special.collection
import special.sigma
import typing


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("special")``.

    collection: special.collection.__module_protocol__
    sigma: special.sigma.__module_protocol__



import java.lang
import java.security
import java.util
import java.util.jar
import typing



class ClassDefinition:
    def __init__(self, class_: typing.Type[typing.Any], byteArray: typing.List[int]): ...
    def getDefinitionClass(self) -> typing.Type[typing.Any]: ...
    def getDefinitionClassFile(self) -> typing.List[int]: ...

class ClassFileTransformer:
    @typing.overload
    def transform(self, classLoader: java.lang.ClassLoader, string: str, class2: typing.Type[typing.Any], protectionDomain: java.security.ProtectionDomain, byteArray: typing.List[int]) -> typing.List[int]: ...
    @typing.overload
    def transform(self, module: java.lang.Module, classLoader: java.lang.ClassLoader, string: str, class2: typing.Type[typing.Any], protectionDomain: java.security.ProtectionDomain, byteArray: typing.List[int]) -> typing.List[int]: ...

class IllegalClassFormatException(java.lang.Exception):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class Instrumentation:
    @typing.overload
    def addTransformer(self, classFileTransformer: ClassFileTransformer) -> None: ...
    @typing.overload
    def addTransformer(self, classFileTransformer: ClassFileTransformer, boolean: bool) -> None: ...
    def appendToBootstrapClassLoaderSearch(self, jarFile: java.util.jar.JarFile) -> None: ...
    def appendToSystemClassLoaderSearch(self, jarFile: java.util.jar.JarFile) -> None: ...
    def getAllLoadedClasses(self) -> typing.List[typing.Type]: ...
    def getInitiatedClasses(self, classLoader: java.lang.ClassLoader) -> typing.List[typing.Type]: ...
    def getObjectSize(self, object: typing.Any) -> int: ...
    def isModifiableClass(self, class_: typing.Type[typing.Any]) -> bool: ...
    def isModifiableModule(self, module: java.lang.Module) -> bool: ...
    def isNativeMethodPrefixSupported(self) -> bool: ...
    def isRedefineClassesSupported(self) -> bool: ...
    def isRetransformClassesSupported(self) -> bool: ...
    def redefineClasses(self, classDefinitionArray: typing.List[ClassDefinition]) -> None: ...
    def redefineModule(self, module: java.lang.Module, set: java.util.Set[java.lang.Module], map: typing.Union[java.util.Map[str, java.util.Set[java.lang.Module]], typing.Mapping[str, java.util.Set[java.lang.Module]]], map2: typing.Union[java.util.Map[str, java.util.Set[java.lang.Module]], typing.Mapping[str, java.util.Set[java.lang.Module]]], set2: java.util.Set[typing.Type[typing.Any]], map3: typing.Union[java.util.Map[typing.Type[typing.Any], java.util.List[typing.Type[typing.Any]]], typing.Mapping[typing.Type[typing.Any], java.util.List[typing.Type[typing.Any]]]]) -> None: ...
    def removeTransformer(self, classFileTransformer: ClassFileTransformer) -> bool: ...
    def retransformClasses(self, classArray: typing.List[typing.Type[typing.Any]]) -> None: ...
    def setNativeMethodPrefix(self, classFileTransformer: ClassFileTransformer, string: str) -> None: ...

class UnmodifiableClassException(java.lang.Exception):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class UnmodifiableModuleException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.lang.instrument")``.

    ClassDefinition: typing.Type[ClassDefinition]
    ClassFileTransformer: typing.Type[ClassFileTransformer]
    IllegalClassFormatException: typing.Type[IllegalClassFormatException]
    Instrumentation: typing.Type[Instrumentation]
    UnmodifiableClassException: typing.Type[UnmodifiableClassException]
    UnmodifiableModuleException: typing.Type[UnmodifiableModuleException]



import java.io
import java.lang
import java.lang.reflect
import java.net
import java.rmi
import typing



class ExportException(java.rmi.RemoteException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, exception: java.lang.Exception): ...

class LoaderHandler:
    packagePrefix: typing.ClassVar[str] = ...
    def getSecurityContext(self, classLoader: java.lang.ClassLoader) -> typing.Any: ...
    @typing.overload
    def loadClass(self, string: str) -> typing.Type[typing.Any]: ...
    @typing.overload
    def loadClass(self, uRL: java.net.URL, string: str) -> typing.Type[typing.Any]: ...

class LogStream(java.io.PrintStream):
    SILENT: typing.ClassVar[int] = ...
    BRIEF: typing.ClassVar[int] = ...
    VERBOSE: typing.ClassVar[int] = ...
    @staticmethod
    def getDefaultStream() -> java.io.PrintStream: ...
    def getOutputStream(self) -> java.io.OutputStream: ...
    @staticmethod
    def log(string: str) -> 'LogStream': ...
    @staticmethod
    def parseLevel(string: str) -> int: ...
    @staticmethod
    def setDefaultStream(printStream: java.io.PrintStream) -> None: ...
    def setOutputStream(self, outputStream: java.io.OutputStream) -> None: ...
    def toString(self) -> str: ...
    @typing.overload
    def write(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def write(self, byteArray: typing.List[int], int: int, int2: int) -> None: ...
    @typing.overload
    def write(self, int: int) -> None: ...

class ObjID(java.io.Serializable):
    REGISTRY_ID: typing.ClassVar[int] = ...
    ACTIVATOR_ID: typing.ClassVar[int] = ...
    DGC_ID: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, int: int): ...
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    @staticmethod
    def read(objectInput: java.io.ObjectInput) -> 'ObjID': ...
    def toString(self) -> str: ...
    def write(self, objectOutput: java.io.ObjectOutput) -> None: ...

class Operation:
    def __init__(self, string: str): ...
    def getOperation(self) -> str: ...
    def toString(self) -> str: ...

class RMIClassLoader:
    @staticmethod
    def getClassAnnotation(class_: typing.Type[typing.Any]) -> str: ...
    @staticmethod
    def getClassLoader(string: str) -> java.lang.ClassLoader: ...
    @staticmethod
    def getDefaultProviderInstance() -> 'RMIClassLoaderSpi': ...
    @staticmethod
    def getSecurityContext(classLoader: java.lang.ClassLoader) -> typing.Any: ...
    @typing.overload
    @staticmethod
    def loadClass(string: str) -> typing.Type[typing.Any]: ...
    @typing.overload
    @staticmethod
    def loadClass(string: str, string2: str) -> typing.Type[typing.Any]: ...
    @typing.overload
    @staticmethod
    def loadClass(string: str, string2: str, classLoader: java.lang.ClassLoader) -> typing.Type[typing.Any]: ...
    @typing.overload
    @staticmethod
    def loadClass(uRL: java.net.URL, string: str) -> typing.Type[typing.Any]: ...
    @staticmethod
    def loadProxyClass(string: str, stringArray: typing.List[str], classLoader: java.lang.ClassLoader) -> typing.Type[typing.Any]: ...

class RMIClassLoaderSpi:
    def __init__(self): ...
    def getClassAnnotation(self, class_: typing.Type[typing.Any]) -> str: ...
    def getClassLoader(self, string: str) -> java.lang.ClassLoader: ...
    def loadClass(self, string: str, string2: str, classLoader: java.lang.ClassLoader) -> typing.Type[typing.Any]: ...
    def loadProxyClass(self, string: str, stringArray: typing.List[str], classLoader: java.lang.ClassLoader) -> typing.Type[typing.Any]: ...

class RMIClientSocketFactory:
    def createSocket(self, string: str, int: int) -> java.net.Socket: ...

class RMIFailureHandler:
    def failure(self, exception: java.lang.Exception) -> bool: ...

class RMIServerSocketFactory:
    def createServerSocket(self, int: int) -> java.net.ServerSocket: ...

class RemoteCall:
    def done(self) -> None: ...
    def executeCall(self) -> None: ...
    def getInputStream(self) -> java.io.ObjectInput: ...
    def getOutputStream(self) -> java.io.ObjectOutput: ...
    def getResultStream(self, boolean: bool) -> java.io.ObjectOutput: ...
    def releaseInputStream(self) -> None: ...
    def releaseOutputStream(self) -> None: ...

class RemoteObject(java.rmi.Remote, java.io.Serializable):
    def equals(self, object: typing.Any) -> bool: ...
    def getRef(self) -> 'RemoteRef': ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    @staticmethod
    def toStub(remote: java.rmi.Remote) -> java.rmi.Remote: ...

class RemoteRef(java.io.Externalizable):
    serialVersionUID: typing.ClassVar[int] = ...
    packagePrefix: typing.ClassVar[str] = ...
    def done(self, remoteCall: RemoteCall) -> None: ...
    def getRefClass(self, objectOutput: java.io.ObjectOutput) -> str: ...
    @typing.overload
    def invoke(self, remote: java.rmi.Remote, method: java.lang.reflect.Method, objectArray: typing.List[typing.Any], long: int) -> typing.Any: ...
    @typing.overload
    def invoke(self, remoteCall: RemoteCall) -> None: ...
    def newCall(self, remoteObject: RemoteObject, operationArray: typing.List[Operation], int: int, long: int) -> RemoteCall: ...
    def remoteEquals(self, remoteRef: 'RemoteRef') -> bool: ...
    def remoteHashCode(self) -> int: ...
    def remoteToString(self) -> str: ...

class ServerCloneException(java.lang.CloneNotSupportedException):
    detail: java.lang.Exception = ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, exception: java.lang.Exception): ...
    def getCause(self) -> java.lang.Throwable: ...
    def getMessage(self) -> str: ...

class ServerNotActiveException(java.lang.Exception):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class Skeleton:
    def dispatch(self, remote: java.rmi.Remote, remoteCall: RemoteCall, int: int, long: int) -> None: ...
    def getOperations(self) -> typing.List[Operation]: ...

class SkeletonMismatchException(java.rmi.RemoteException):
    def __init__(self, string: str): ...

class SkeletonNotFoundException(java.rmi.RemoteException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, exception: java.lang.Exception): ...

class UID(java.io.Serializable):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, short: int): ...
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    @staticmethod
    def read(dataInput: java.io.DataInput) -> 'UID': ...
    def toString(self) -> str: ...
    def write(self, dataOutput: java.io.DataOutput) -> None: ...

class Unreferenced:
    def unreferenced(self) -> None: ...

class RMISocketFactory(RMIClientSocketFactory, RMIServerSocketFactory):
    def __init__(self): ...
    def createServerSocket(self, int: int) -> java.net.ServerSocket: ...
    def createSocket(self, string: str, int: int) -> java.net.Socket: ...
    @staticmethod
    def getDefaultSocketFactory() -> 'RMISocketFactory': ...
    @staticmethod
    def getFailureHandler() -> RMIFailureHandler: ...
    @staticmethod
    def getSocketFactory() -> 'RMISocketFactory': ...
    @staticmethod
    def setFailureHandler(rMIFailureHandler: RMIFailureHandler) -> None: ...
    @staticmethod
    def setSocketFactory(rMISocketFactory: 'RMISocketFactory') -> None: ...

class RemoteObjectInvocationHandler(RemoteObject, java.lang.reflect.InvocationHandler):
    def __init__(self, remoteRef: RemoteRef): ...
    def invoke(self, object: typing.Any, method: java.lang.reflect.Method, objectArray: typing.List[typing.Any]) -> typing.Any: ...

class RemoteServer(RemoteObject):
    @staticmethod
    def getClientHost() -> str: ...
    @staticmethod
    def getLog() -> java.io.PrintStream: ...
    @staticmethod
    def setLog(outputStream: java.io.OutputStream) -> None: ...

class RemoteStub(RemoteObject): ...

class ServerRef(RemoteRef):
    serialVersionUID: typing.ClassVar[int] = ...
    def exportObject(self, remote: java.rmi.Remote, object: typing.Any) -> RemoteStub: ...
    def getClientHost(self) -> str: ...

class SocketSecurityException(ExportException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, exception: java.lang.Exception): ...

class UnicastRemoteObject(RemoteServer):
    def clone(self) -> typing.Any: ...
    @typing.overload
    @staticmethod
    def exportObject(remote: java.rmi.Remote, int: int) -> java.rmi.Remote: ...
    @typing.overload
    @staticmethod
    def exportObject(remote: java.rmi.Remote, int: int, objectInputFilter: typing.Union[java.io.ObjectInputFilter, typing.Callable]) -> java.rmi.Remote: ...
    @typing.overload
    @staticmethod
    def exportObject(remote: java.rmi.Remote, int: int, rMIClientSocketFactory: RMIClientSocketFactory, rMIServerSocketFactory: RMIServerSocketFactory) -> java.rmi.Remote: ...
    @typing.overload
    @staticmethod
    def exportObject(remote: java.rmi.Remote, int: int, rMIClientSocketFactory: RMIClientSocketFactory, rMIServerSocketFactory: RMIServerSocketFactory, objectInputFilter: typing.Union[java.io.ObjectInputFilter, typing.Callable]) -> java.rmi.Remote: ...
    @typing.overload
    @staticmethod
    def exportObject(remote: java.rmi.Remote) -> RemoteStub: ...
    @staticmethod
    def unexportObject(remote: java.rmi.Remote, boolean: bool) -> bool: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.rmi.server")``.

    ExportException: typing.Type[ExportException]
    LoaderHandler: typing.Type[LoaderHandler]
    LogStream: typing.Type[LogStream]
    ObjID: typing.Type[ObjID]
    Operation: typing.Type[Operation]
    RMIClassLoader: typing.Type[RMIClassLoader]
    RMIClassLoaderSpi: typing.Type[RMIClassLoaderSpi]
    RMIClientSocketFactory: typing.Type[RMIClientSocketFactory]
    RMIFailureHandler: typing.Type[RMIFailureHandler]
    RMIServerSocketFactory: typing.Type[RMIServerSocketFactory]
    RMISocketFactory: typing.Type[RMISocketFactory]
    RemoteCall: typing.Type[RemoteCall]
    RemoteObject: typing.Type[RemoteObject]
    RemoteObjectInvocationHandler: typing.Type[RemoteObjectInvocationHandler]
    RemoteRef: typing.Type[RemoteRef]
    RemoteServer: typing.Type[RemoteServer]
    RemoteStub: typing.Type[RemoteStub]
    ServerCloneException: typing.Type[ServerCloneException]
    ServerNotActiveException: typing.Type[ServerNotActiveException]
    ServerRef: typing.Type[ServerRef]
    Skeleton: typing.Type[Skeleton]
    SkeletonMismatchException: typing.Type[SkeletonMismatchException]
    SkeletonNotFoundException: typing.Type[SkeletonNotFoundException]
    SocketSecurityException: typing.Type[SocketSecurityException]
    UID: typing.Type[UID]
    UnicastRemoteObject: typing.Type[UnicastRemoteObject]
    Unreferenced: typing.Type[Unreferenced]



import java.io
import java.lang
import java.util
import typing



class Clipboard:
    def __init__(self, string: str): ...
    def addFlavorListener(self, flavorListener: 'FlavorListener') -> None: ...
    def getAvailableDataFlavors(self) -> typing.List['DataFlavor']: ...
    def getContents(self, object: typing.Any) -> 'Transferable': ...
    def getData(self, dataFlavor: 'DataFlavor') -> typing.Any: ...
    def getFlavorListeners(self) -> typing.List['FlavorListener']: ...
    def getName(self) -> str: ...
    def isDataFlavorAvailable(self, dataFlavor: 'DataFlavor') -> bool: ...
    def removeFlavorListener(self, flavorListener: 'FlavorListener') -> None: ...
    def setContents(self, transferable: 'Transferable', clipboardOwner: 'ClipboardOwner') -> None: ...

class ClipboardOwner:
    def lostOwnership(self, clipboard: Clipboard, transferable: 'Transferable') -> None: ...

class DataFlavor(java.io.Externalizable, java.lang.Cloneable):
    stringFlavor: typing.ClassVar['DataFlavor'] = ...
    imageFlavor: typing.ClassVar['DataFlavor'] = ...
    plainTextFlavor: typing.ClassVar['DataFlavor'] = ...
    javaSerializedObjectMimeType: typing.ClassVar[str] = ...
    javaFileListFlavor: typing.ClassVar['DataFlavor'] = ...
    javaJVMLocalObjectMimeType: typing.ClassVar[str] = ...
    javaRemoteObjectMimeType: typing.ClassVar[str] = ...
    selectionHtmlFlavor: typing.ClassVar['DataFlavor'] = ...
    fragmentHtmlFlavor: typing.ClassVar['DataFlavor'] = ...
    allHtmlFlavor: typing.ClassVar['DataFlavor'] = ...
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, class_: typing.Type[typing.Any], string: str): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str, classLoader: java.lang.ClassLoader): ...
    def clone(self) -> typing.Any: ...
    @typing.overload
    def equals(self, dataFlavor: 'DataFlavor') -> bool: ...
    @typing.overload
    def equals(self, object: typing.Any) -> bool: ...
    @typing.overload
    def equals(self, string: str) -> bool: ...
    def getDefaultRepresentationClass(self) -> typing.Type[typing.Any]: ...
    def getDefaultRepresentationClassAsString(self) -> str: ...
    def getHumanPresentableName(self) -> str: ...
    def getMimeType(self) -> str: ...
    def getParameter(self, string: str) -> str: ...
    def getPrimaryType(self) -> str: ...
    def getReaderForText(self, transferable: 'Transferable') -> java.io.Reader: ...
    def getRepresentationClass(self) -> typing.Type[typing.Any]: ...
    def getSubType(self) -> str: ...
    @staticmethod
    def getTextPlainUnicodeFlavor() -> 'DataFlavor': ...
    def hashCode(self) -> int: ...
    def isFlavorJavaFileListType(self) -> bool: ...
    def isFlavorRemoteObjectType(self) -> bool: ...
    def isFlavorSerializedObjectType(self) -> bool: ...
    def isFlavorTextType(self) -> bool: ...
    @typing.overload
    def isMimeTypeEqual(self, string: str) -> bool: ...
    @typing.overload
    def isMimeTypeEqual(self, dataFlavor: 'DataFlavor') -> bool: ...
    def isMimeTypeSerializedObject(self) -> bool: ...
    def isRepresentationClassByteBuffer(self) -> bool: ...
    def isRepresentationClassCharBuffer(self) -> bool: ...
    def isRepresentationClassInputStream(self) -> bool: ...
    def isRepresentationClassReader(self) -> bool: ...
    def isRepresentationClassRemote(self) -> bool: ...
    def isRepresentationClassSerializable(self) -> bool: ...
    def match(self, dataFlavor: 'DataFlavor') -> bool: ...
    def readExternal(self, objectInput: java.io.ObjectInput) -> None: ...
    @staticmethod
    def selectBestTextFlavor(dataFlavorArray: typing.List['DataFlavor']) -> 'DataFlavor': ...
    def setHumanPresentableName(self, string: str) -> None: ...
    def toString(self) -> str: ...
    def writeExternal(self, objectOutput: java.io.ObjectOutput) -> None: ...

class FlavorEvent(java.util.EventObject):
    def __init__(self, clipboard: Clipboard): ...

class FlavorListener(java.util.EventListener):
    def flavorsChanged(self, flavorEvent: FlavorEvent) -> None: ...

class FlavorMap:
    def getFlavorsForNatives(self, stringArray: typing.List[str]) -> java.util.Map[str, DataFlavor]: ...
    def getNativesForFlavors(self, dataFlavorArray: typing.List[DataFlavor]) -> java.util.Map[DataFlavor, str]: ...

class MimeTypeParseException(java.lang.Exception):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class Transferable:
    def getTransferData(self, dataFlavor: DataFlavor) -> typing.Any: ...
    def getTransferDataFlavors(self) -> typing.List[DataFlavor]: ...
    def isDataFlavorSupported(self, dataFlavor: DataFlavor) -> bool: ...

class UnsupportedFlavorException(java.lang.Exception):
    def __init__(self, dataFlavor: DataFlavor): ...

class FlavorTable(FlavorMap):
    def getFlavorsForNative(self, string: str) -> java.util.List[DataFlavor]: ...
    def getNativesForFlavor(self, dataFlavor: DataFlavor) -> java.util.List[str]: ...

class StringSelection(Transferable, ClipboardOwner):
    def __init__(self, string: str): ...
    def getTransferData(self, dataFlavor: DataFlavor) -> typing.Any: ...
    def getTransferDataFlavors(self) -> typing.List[DataFlavor]: ...
    def isDataFlavorSupported(self, dataFlavor: DataFlavor) -> bool: ...
    def lostOwnership(self, clipboard: Clipboard, transferable: Transferable) -> None: ...

class SystemFlavorMap(FlavorMap, FlavorTable):
    def addFlavorForUnencodedNative(self, string: str, dataFlavor: DataFlavor) -> None: ...
    def addUnencodedNativeForFlavor(self, dataFlavor: DataFlavor, string: str) -> None: ...
    @staticmethod
    def decodeDataFlavor(string: str) -> DataFlavor: ...
    @staticmethod
    def decodeJavaMIMEType(string: str) -> str: ...
    @staticmethod
    def encodeDataFlavor(dataFlavor: DataFlavor) -> str: ...
    @staticmethod
    def encodeJavaMIMEType(string: str) -> str: ...
    @staticmethod
    def getDefaultFlavorMap() -> FlavorMap: ...
    def getFlavorsForNative(self, string: str) -> java.util.List[DataFlavor]: ...
    def getFlavorsForNatives(self, stringArray: typing.List[str]) -> java.util.Map[str, DataFlavor]: ...
    def getNativesForFlavor(self, dataFlavor: DataFlavor) -> java.util.List[str]: ...
    def getNativesForFlavors(self, dataFlavorArray: typing.List[DataFlavor]) -> java.util.Map[DataFlavor, str]: ...
    @staticmethod
    def isJavaMIMEType(string: str) -> bool: ...
    def setFlavorsForNative(self, string: str, dataFlavorArray: typing.List[DataFlavor]) -> None: ...
    def setNativesForFlavor(self, dataFlavor: DataFlavor, stringArray: typing.List[str]) -> None: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.awt.datatransfer")``.

    Clipboard: typing.Type[Clipboard]
    ClipboardOwner: typing.Type[ClipboardOwner]
    DataFlavor: typing.Type[DataFlavor]
    FlavorEvent: typing.Type[FlavorEvent]
    FlavorListener: typing.Type[FlavorListener]
    FlavorMap: typing.Type[FlavorMap]
    FlavorTable: typing.Type[FlavorTable]
    MimeTypeParseException: typing.Type[MimeTypeParseException]
    StringSelection: typing.Type[StringSelection]
    SystemFlavorMap: typing.Type[SystemFlavorMap]
    Transferable: typing.Type[Transferable]
    UnsupportedFlavorException: typing.Type[UnsupportedFlavorException]



import java.io
import java.lang
import java.util.function
import java.util.stream
import typing



class MatchResult:
    @typing.overload
    def end(self) -> int: ...
    @typing.overload
    def end(self, int: int) -> int: ...
    @typing.overload
    def group(self) -> str: ...
    @typing.overload
    def group(self, int: int) -> str: ...
    def groupCount(self) -> int: ...
    @typing.overload
    def start(self) -> int: ...
    @typing.overload
    def start(self, int: int) -> int: ...

class Pattern(java.io.Serializable):
    UNIX_LINES: typing.ClassVar[int] = ...
    CASE_INSENSITIVE: typing.ClassVar[int] = ...
    COMMENTS: typing.ClassVar[int] = ...
    MULTILINE: typing.ClassVar[int] = ...
    LITERAL: typing.ClassVar[int] = ...
    DOTALL: typing.ClassVar[int] = ...
    UNICODE_CASE: typing.ClassVar[int] = ...
    CANON_EQ: typing.ClassVar[int] = ...
    UNICODE_CHARACTER_CLASS: typing.ClassVar[int] = ...
    def asMatchPredicate(self) -> java.util.function.Predicate[str]: ...
    def asPredicate(self) -> java.util.function.Predicate[str]: ...
    @typing.overload
    @staticmethod
    def compile(string: str) -> 'Pattern': ...
    @typing.overload
    @staticmethod
    def compile(string: str, int: int) -> 'Pattern': ...
    def flags(self) -> int: ...
    def matcher(self, charSequence: typing.Union[java.lang.CharSequence, str]) -> 'Matcher': ...
    @staticmethod
    def matches(string: str, charSequence: typing.Union[java.lang.CharSequence, str]) -> bool: ...
    def pattern(self) -> str: ...
    @staticmethod
    def quote(string: str) -> str: ...
    @typing.overload
    def split(self, charSequence: typing.Union[java.lang.CharSequence, str]) -> typing.List[str]: ...
    @typing.overload
    def split(self, charSequence: typing.Union[java.lang.CharSequence, str], int: int) -> typing.List[str]: ...
    def splitAsStream(self, charSequence: typing.Union[java.lang.CharSequence, str]) -> java.util.stream.Stream[str]: ...
    def toString(self) -> str: ...

class PatternSyntaxException(java.lang.IllegalArgumentException):
    def __init__(self, string: str, string2: str, int: int): ...
    def getDescription(self) -> str: ...
    def getIndex(self) -> int: ...
    def getMessage(self) -> str: ...
    def getPattern(self) -> str: ...

class Matcher(MatchResult):
    @typing.overload
    def appendReplacement(self, stringBuffer: java.lang.StringBuffer, string2: str) -> 'Matcher': ...
    @typing.overload
    def appendReplacement(self, stringBuilder: java.lang.StringBuilder, string2: str) -> 'Matcher': ...
    @typing.overload
    def appendTail(self, stringBuffer: java.lang.StringBuffer) -> java.lang.StringBuffer: ...
    @typing.overload
    def appendTail(self, stringBuilder: java.lang.StringBuilder) -> java.lang.StringBuilder: ...
    @typing.overload
    def end(self) -> int: ...
    @typing.overload
    def end(self, int: int) -> int: ...
    @typing.overload
    def end(self, string: str) -> int: ...
    @typing.overload
    def find(self) -> bool: ...
    @typing.overload
    def find(self, int: int) -> bool: ...
    @typing.overload
    def group(self) -> str: ...
    @typing.overload
    def group(self, int: int) -> str: ...
    @typing.overload
    def group(self, string: str) -> str: ...
    def groupCount(self) -> int: ...
    def hasAnchoringBounds(self) -> bool: ...
    def hasTransparentBounds(self) -> bool: ...
    def hitEnd(self) -> bool: ...
    def lookingAt(self) -> bool: ...
    def matches(self) -> bool: ...
    def pattern(self) -> Pattern: ...
    @staticmethod
    def quoteReplacement(string: str) -> str: ...
    def region(self, int: int, int2: int) -> 'Matcher': ...
    def regionEnd(self) -> int: ...
    def regionStart(self) -> int: ...
    @typing.overload
    def replaceAll(self, string: str) -> str: ...
    @typing.overload
    def replaceAll(self, function: typing.Union[java.util.function.Function[MatchResult, str], typing.Callable[[MatchResult], str]]) -> str: ...
    @typing.overload
    def replaceFirst(self, string: str) -> str: ...
    @typing.overload
    def replaceFirst(self, function: typing.Union[java.util.function.Function[MatchResult, str], typing.Callable[[MatchResult], str]]) -> str: ...
    def requireEnd(self) -> bool: ...
    @typing.overload
    def reset(self) -> 'Matcher': ...
    @typing.overload
    def reset(self, charSequence: typing.Union[java.lang.CharSequence, str]) -> 'Matcher': ...
    def results(self) -> java.util.stream.Stream[MatchResult]: ...
    @typing.overload
    def start(self) -> int: ...
    @typing.overload
    def start(self, int: int) -> int: ...
    @typing.overload
    def start(self, string: str) -> int: ...
    def toMatchResult(self) -> MatchResult: ...
    def toString(self) -> str: ...
    def useAnchoringBounds(self, boolean: bool) -> 'Matcher': ...
    def usePattern(self, pattern: Pattern) -> 'Matcher': ...
    def useTransparentBounds(self, boolean: bool) -> 'Matcher': ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.util.regex")``.

    MatchResult: typing.Type[MatchResult]
    Matcher: typing.Type[Matcher]
    Pattern: typing.Type[Pattern]
    PatternSyntaxException: typing.Type[PatternSyntaxException]



import cats.data
import io.circe
import java.lang
import scala
import scala.collection
import scala.collection.immutable
import scala.util
import typing



class EncryptionSettings(scala.Product, scala.Serializable):
    def __init__(self, prf: typing.Union[java.lang.String, str], c: int, dkLen: int): ...
    @staticmethod
    def apply(prf: typing.Union[java.lang.String, str], c: int, dkLen: int) -> 'EncryptionSettings': ...
    def c(self) -> int: ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def copy(self, prf: typing.Union[java.lang.String, str], c: int, dkLen: int) -> 'EncryptionSettings': ...
    def copy$default$1(self) -> java.lang.String: ...
    def copy$default$2(self) -> int: ...
    def copy$default$3(self) -> int: ...
    def dkLen(self) -> int: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def prf(self) -> java.lang.String: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    def toString(self) -> java.lang.String: ...
    @staticmethod
    def unapply(x$0: 'EncryptionSettings') -> scala.Option[scala.Tuple3[java.lang.String, typing.Any, typing.Any]]: ...
    class EncryptionSettingsDecoder$(io.circe.Decoder['EncryptionSettings']):
        MODULE$: typing.ClassVar['EncryptionSettings.EncryptionSettingsDecoder.'] = ...
        def __init__(self): ...
        def accumulating(self, c: io.circe.HCursor) -> cats.data.Validated[cats.data.NonEmptyList[io.circe.DecodingFailure], 'EncryptionSettings']: ...
        def apply(self, cursor: io.circe.HCursor) -> scala.util.Either[io.circe.DecodingFailure, 'EncryptionSettings']: ...
        def at(self, field: typing.Union[java.lang.String, str]) -> io.circe.Decoder['EncryptionSettings']: ...
        def decodeAccumulating(self, c: io.circe.HCursor) -> cats.data.Validated[cats.data.NonEmptyList[io.circe.DecodingFailure], 'EncryptionSettings']: ...
        def decodeJson(self, j: io.circe.Json) -> scala.util.Either[io.circe.DecodingFailure, 'EncryptionSettings']: ...
        _either__B = typing.TypeVar('_either__B')  # <B>
        def either(self, decodeB: io.circe.Decoder[_either__B]) -> io.circe.Decoder[scala.util.Either['EncryptionSettings', _either__B]]: ...
        _emap__B = typing.TypeVar('_emap__B')  # <B>
        def emap(self, f: scala.Function1['EncryptionSettings', scala.util.Either[typing.Union[java.lang.String, str], _emap__B]]) -> io.circe.Decoder[_emap__B]: ...
        _emapTry__B = typing.TypeVar('_emapTry__B')  # <B>
        def emapTry(self, f: scala.Function1['EncryptionSettings', scala.util.Try[_emapTry__B]]) -> io.circe.Decoder[_emapTry__B]: ...
        @typing.overload
        def ensure(self, errors: scala.Function1['EncryptionSettings', scala.collection.immutable.List[typing.Union[java.lang.String, str]]]) -> io.circe.Decoder['EncryptionSettings']: ...
        @typing.overload
        def ensure(self, pred: scala.Function1['EncryptionSettings', typing.Any], message: scala.Function0[typing.Union[java.lang.String, str]]) -> io.circe.Decoder['EncryptionSettings']: ...
        _flatMap__B = typing.TypeVar('_flatMap__B')  # <B>
        def flatMap(self, f: scala.Function1['EncryptionSettings', io.circe.Decoder[_flatMap__B]]) -> io.circe.Decoder[_flatMap__B]: ...
        def handleErrorWith(self, f: scala.Function1[io.circe.DecodingFailure, io.circe.Decoder['EncryptionSettings']]) -> io.circe.Decoder['EncryptionSettings']: ...
        def kleisli(self) -> cats.data.Kleisli[scala.util.Either, io.circe.HCursor, 'EncryptionSettings']: ...
        _map__B = typing.TypeVar('_map__B')  # <B>
        def map(self, f: scala.Function1['EncryptionSettings', _map__B]) -> io.circe.Decoder[_map__B]: ...
        def prepare(self, f: scala.Function1[io.circe.ACursor, io.circe.ACursor]) -> io.circe.Decoder['EncryptionSettings']: ...
        _product__B = typing.TypeVar('_product__B')  # <B>
        def product(self, fb: io.circe.Decoder[_product__B]) -> io.circe.Decoder[scala.Tuple2['EncryptionSettings', _product__B]]: ...
        def tryDecode(self, c: io.circe.ACursor) -> scala.util.Either[io.circe.DecodingFailure, 'EncryptionSettings']: ...
        def tryDecodeAccumulating(self, c: io.circe.ACursor) -> cats.data.Validated[cats.data.NonEmptyList[io.circe.DecodingFailure], 'EncryptionSettings']: ...
        @typing.overload
        def validate(self, errors: scala.Function1[io.circe.HCursor, scala.collection.immutable.List[typing.Union[java.lang.String, str]]]) -> io.circe.Decoder['EncryptionSettings']: ...
        @typing.overload
        def validate(self, pred: scala.Function1[io.circe.HCursor, typing.Any], message: scala.Function0[typing.Union[java.lang.String, str]]) -> io.circe.Decoder['EncryptionSettings']: ...
        def withErrorMessage(self, message: typing.Union[java.lang.String, str]) -> io.circe.Decoder['EncryptionSettings']: ...
    class EncryptionSettingsEncoder$(io.circe.Encoder['EncryptionSettings']):
        MODULE$: typing.ClassVar['EncryptionSettings.EncryptionSettingsEncoder.'] = ...
        def __init__(self): ...
        def apply(self, s: 'EncryptionSettings') -> io.circe.Json: ...
        _contramap__B = typing.TypeVar('_contramap__B')  # <B>
        def contramap(self, f: scala.Function1[_contramap__B, 'EncryptionSettings']) -> io.circe.Encoder[_contramap__B]: ...
        def mapJson(self, f: scala.Function1[io.circe.Json, io.circe.Json]) -> io.circe.Encoder['EncryptionSettings']: ...

class SecretStorageSettings(scala.Product, scala.Serializable):
    def __init__(self, secretDir: typing.Union[java.lang.String, str], encryption: EncryptionSettings): ...
    @staticmethod
    def apply(secretDir: typing.Union[java.lang.String, str], encryption: EncryptionSettings) -> 'SecretStorageSettings': ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def copy(self, secretDir: typing.Union[java.lang.String, str], encryption: EncryptionSettings) -> 'SecretStorageSettings': ...
    def copy$default$1(self) -> java.lang.String: ...
    def copy$default$2(self) -> EncryptionSettings: ...
    @staticmethod
    def curried() -> scala.Function1[java.lang.String, scala.Function1[EncryptionSettings, 'SecretStorageSettings']]: ...
    def encryption(self) -> EncryptionSettings: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    def secretDir(self) -> java.lang.String: ...
    def toString(self) -> java.lang.String: ...
    @staticmethod
    def tupled() -> scala.Function1[scala.Tuple2[java.lang.String, EncryptionSettings], 'SecretStorageSettings']: ...
    @staticmethod
    def unapply(x$0: 'SecretStorageSettings') -> scala.Option[scala.Tuple2[java.lang.String, EncryptionSettings]]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.wallet.settings")``.

    EncryptionSettings: typing.Type[EncryptionSettings]
    SecretStorageSettings: typing.Type[SecretStorageSettings]



import java.io
import java.lang
import java.net
import java.nio.channels
import java.nio.charset
import java.nio.file.attribute
import java.nio.file.spi
import java.security
import java.util
import java.util.concurrent
import java.util.function
import java.util.stream
import jpype.protocol
import typing



class AccessMode(java.lang.Enum['AccessMode']):
    READ: typing.ClassVar['AccessMode'] = ...
    WRITE: typing.ClassVar['AccessMode'] = ...
    EXECUTE: typing.ClassVar['AccessMode'] = ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'AccessMode': ...
    @staticmethod
    def values() -> typing.List['AccessMode']: ...

class ClosedDirectoryStreamException(java.lang.IllegalStateException):
    def __init__(self): ...

class ClosedFileSystemException(java.lang.IllegalStateException):
    def __init__(self): ...

class ClosedWatchServiceException(java.lang.IllegalStateException):
    def __init__(self): ...

class CopyOption: ...

class DirectoryIteratorException(java.util.ConcurrentModificationException):
    def __init__(self, iOException: java.io.IOException): ...
    def getCause(self) -> java.io.IOException: ...

_DirectoryStream__Filter__T = typing.TypeVar('_DirectoryStream__Filter__T')  # <T>
_DirectoryStream__T = typing.TypeVar('_DirectoryStream__T')  # <T>
class DirectoryStream(java.io.Closeable, java.lang.Iterable[_DirectoryStream__T], typing.Generic[_DirectoryStream__T]):
    def iterator(self) -> java.util.Iterator[_DirectoryStream__T]: ...
    class Filter(typing.Generic[_DirectoryStream__Filter__T]):
        def accept(self, t: _DirectoryStream__Filter__T) -> bool: ...

class FileStore:
    def getAttribute(self, string: str) -> typing.Any: ...
    def getBlockSize(self) -> int: ...
    _getFileStoreAttributeView__V = typing.TypeVar('_getFileStoreAttributeView__V', bound=java.nio.file.attribute.FileStoreAttributeView)  # <V>
    def getFileStoreAttributeView(self, class_: typing.Type[_getFileStoreAttributeView__V]) -> _getFileStoreAttributeView__V: ...
    def getTotalSpace(self) -> int: ...
    def getUnallocatedSpace(self) -> int: ...
    def getUsableSpace(self) -> int: ...
    def isReadOnly(self) -> bool: ...
    def name(self) -> str: ...
    @typing.overload
    def supportsFileAttributeView(self, class_: typing.Type[java.nio.file.attribute.FileAttributeView]) -> bool: ...
    @typing.overload
    def supportsFileAttributeView(self, string: str) -> bool: ...
    def type(self) -> str: ...

class FileSystem(java.io.Closeable):
    def close(self) -> None: ...
    def getFileStores(self) -> java.lang.Iterable[FileStore]: ...
    def getPath(self, string: str, stringArray: typing.List[str]) -> 'Path': ...
    def getPathMatcher(self, string: str) -> 'PathMatcher': ...
    def getRootDirectories(self) -> java.lang.Iterable['Path']: ...
    def getSeparator(self) -> str: ...
    def getUserPrincipalLookupService(self) -> java.nio.file.attribute.UserPrincipalLookupService: ...
    def isOpen(self) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def newWatchService(self) -> 'WatchService': ...
    def provider(self) -> java.nio.file.spi.FileSystemProvider: ...
    def supportedFileAttributeViews(self) -> java.util.Set[str]: ...

class FileSystemAlreadyExistsException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class FileSystemException(java.io.IOException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str, string3: str): ...
    def getFile(self) -> str: ...
    def getMessage(self) -> str: ...
    def getOtherFile(self) -> str: ...
    def getReason(self) -> str: ...

class FileSystemNotFoundException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class FileSystems:
    @staticmethod
    def getDefault() -> FileSystem: ...
    @staticmethod
    def getFileSystem(uRI: java.net.URI) -> FileSystem: ...
    @typing.overload
    @staticmethod
    def newFileSystem(uRI: java.net.URI, map: typing.Union[java.util.Map[str, typing.Any], typing.Mapping[str, typing.Any]]) -> FileSystem: ...
    @typing.overload
    @staticmethod
    def newFileSystem(uRI: java.net.URI, map: typing.Union[java.util.Map[str, typing.Any], typing.Mapping[str, typing.Any]], classLoader: java.lang.ClassLoader) -> FileSystem: ...
    @typing.overload
    @staticmethod
    def newFileSystem(path: typing.Union['Path', jpype.protocol.SupportsPath], classLoader: java.lang.ClassLoader) -> FileSystem: ...

class FileVisitOption(java.lang.Enum['FileVisitOption']):
    FOLLOW_LINKS: typing.ClassVar['FileVisitOption'] = ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'FileVisitOption': ...
    @staticmethod
    def values() -> typing.List['FileVisitOption']: ...

class FileVisitResult(java.lang.Enum['FileVisitResult']):
    CONTINUE: typing.ClassVar['FileVisitResult'] = ...
    TERMINATE: typing.ClassVar['FileVisitResult'] = ...
    SKIP_SUBTREE: typing.ClassVar['FileVisitResult'] = ...
    SKIP_SIBLINGS: typing.ClassVar['FileVisitResult'] = ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'FileVisitResult': ...
    @staticmethod
    def values() -> typing.List['FileVisitResult']: ...

_FileVisitor__T = typing.TypeVar('_FileVisitor__T')  # <T>
class FileVisitor(typing.Generic[_FileVisitor__T]):
    def postVisitDirectory(self, t: _FileVisitor__T, iOException: java.io.IOException) -> FileVisitResult: ...
    def preVisitDirectory(self, t: _FileVisitor__T, basicFileAttributes: java.nio.file.attribute.BasicFileAttributes) -> FileVisitResult: ...
    def visitFile(self, t: _FileVisitor__T, basicFileAttributes: java.nio.file.attribute.BasicFileAttributes) -> FileVisitResult: ...
    def visitFileFailed(self, t: _FileVisitor__T, iOException: java.io.IOException) -> FileVisitResult: ...

class Files:
    @typing.overload
    @staticmethod
    def copy(path: typing.Union['Path', jpype.protocol.SupportsPath], path2: typing.Union['Path', jpype.protocol.SupportsPath], copyOptionArray: typing.List[CopyOption]) -> 'Path': ...
    @typing.overload
    @staticmethod
    def copy(inputStream: java.io.InputStream, path: typing.Union['Path', jpype.protocol.SupportsPath], copyOptionArray: typing.List[CopyOption]) -> int: ...
    @typing.overload
    @staticmethod
    def copy(path: typing.Union['Path', jpype.protocol.SupportsPath], outputStream: java.io.OutputStream) -> int: ...
    @staticmethod
    def createDirectories(path: typing.Union['Path', jpype.protocol.SupportsPath], fileAttributeArray: typing.List[java.nio.file.attribute.FileAttribute[typing.Any]]) -> 'Path': ...
    @staticmethod
    def createDirectory(path: typing.Union['Path', jpype.protocol.SupportsPath], fileAttributeArray: typing.List[java.nio.file.attribute.FileAttribute[typing.Any]]) -> 'Path': ...
    @staticmethod
    def createFile(path: typing.Union['Path', jpype.protocol.SupportsPath], fileAttributeArray: typing.List[java.nio.file.attribute.FileAttribute[typing.Any]]) -> 'Path': ...
    @staticmethod
    def createLink(path: typing.Union['Path', jpype.protocol.SupportsPath], path2: typing.Union['Path', jpype.protocol.SupportsPath]) -> 'Path': ...
    @staticmethod
    def createSymbolicLink(path: typing.Union['Path', jpype.protocol.SupportsPath], path2: typing.Union['Path', jpype.protocol.SupportsPath], fileAttributeArray: typing.List[java.nio.file.attribute.FileAttribute[typing.Any]]) -> 'Path': ...
    @typing.overload
    @staticmethod
    def createTempDirectory(string: str, fileAttributeArray: typing.List[java.nio.file.attribute.FileAttribute[typing.Any]]) -> 'Path': ...
    @typing.overload
    @staticmethod
    def createTempDirectory(path: typing.Union['Path', jpype.protocol.SupportsPath], string: str, fileAttributeArray: typing.List[java.nio.file.attribute.FileAttribute[typing.Any]]) -> 'Path': ...
    @typing.overload
    @staticmethod
    def createTempFile(string: str, string2: str, fileAttributeArray: typing.List[java.nio.file.attribute.FileAttribute[typing.Any]]) -> 'Path': ...
    @typing.overload
    @staticmethod
    def createTempFile(path: typing.Union['Path', jpype.protocol.SupportsPath], string: str, string2: str, fileAttributeArray: typing.List[java.nio.file.attribute.FileAttribute[typing.Any]]) -> 'Path': ...
    @staticmethod
    def delete(path: typing.Union['Path', jpype.protocol.SupportsPath]) -> None: ...
    @staticmethod
    def deleteIfExists(path: typing.Union['Path', jpype.protocol.SupportsPath]) -> bool: ...
    @staticmethod
    def exists(path: typing.Union['Path', jpype.protocol.SupportsPath], linkOptionArray: typing.List['LinkOption']) -> bool: ...
    @staticmethod
    def find(path: typing.Union['Path', jpype.protocol.SupportsPath], int: int, biPredicate: typing.Union[java.util.function.BiPredicate[typing.Union['Path', jpype.protocol.SupportsPath], java.nio.file.attribute.BasicFileAttributes], typing.Callable[[typing.Union['Path', jpype.protocol.SupportsPath], java.nio.file.attribute.BasicFileAttributes], bool]], fileVisitOptionArray: typing.List[FileVisitOption]) -> java.util.stream.Stream['Path']: ...
    @staticmethod
    def getAttribute(path: typing.Union['Path', jpype.protocol.SupportsPath], string: str, linkOptionArray: typing.List['LinkOption']) -> typing.Any: ...
    _getFileAttributeView__V = typing.TypeVar('_getFileAttributeView__V', bound=java.nio.file.attribute.FileAttributeView)  # <V>
    @staticmethod
    def getFileAttributeView(path: typing.Union['Path', jpype.protocol.SupportsPath], class_: typing.Type[_getFileAttributeView__V], linkOptionArray: typing.List['LinkOption']) -> _getFileAttributeView__V: ...
    @staticmethod
    def getFileStore(path: typing.Union['Path', jpype.protocol.SupportsPath]) -> FileStore: ...
    @staticmethod
    def getLastModifiedTime(path: typing.Union['Path', jpype.protocol.SupportsPath], linkOptionArray: typing.List['LinkOption']) -> java.nio.file.attribute.FileTime: ...
    @staticmethod
    def getOwner(path: typing.Union['Path', jpype.protocol.SupportsPath], linkOptionArray: typing.List['LinkOption']) -> java.nio.file.attribute.UserPrincipal: ...
    @staticmethod
    def getPosixFilePermissions(path: typing.Union['Path', jpype.protocol.SupportsPath], linkOptionArray: typing.List['LinkOption']) -> java.util.Set[java.nio.file.attribute.PosixFilePermission]: ...
    @staticmethod
    def isDirectory(path: typing.Union['Path', jpype.protocol.SupportsPath], linkOptionArray: typing.List['LinkOption']) -> bool: ...
    @staticmethod
    def isExecutable(path: typing.Union['Path', jpype.protocol.SupportsPath]) -> bool: ...
    @staticmethod
    def isHidden(path: typing.Union['Path', jpype.protocol.SupportsPath]) -> bool: ...
    @staticmethod
    def isReadable(path: typing.Union['Path', jpype.protocol.SupportsPath]) -> bool: ...
    @staticmethod
    def isRegularFile(path: typing.Union['Path', jpype.protocol.SupportsPath], linkOptionArray: typing.List['LinkOption']) -> bool: ...
    @staticmethod
    def isSameFile(path: typing.Union['Path', jpype.protocol.SupportsPath], path2: typing.Union['Path', jpype.protocol.SupportsPath]) -> bool: ...
    @staticmethod
    def isSymbolicLink(path: typing.Union['Path', jpype.protocol.SupportsPath]) -> bool: ...
    @staticmethod
    def isWritable(path: typing.Union['Path', jpype.protocol.SupportsPath]) -> bool: ...
    @typing.overload
    @staticmethod
    def lines(path: typing.Union['Path', jpype.protocol.SupportsPath]) -> java.util.stream.Stream[str]: ...
    @typing.overload
    @staticmethod
    def lines(path: typing.Union['Path', jpype.protocol.SupportsPath], charset: java.nio.charset.Charset) -> java.util.stream.Stream[str]: ...
    @staticmethod
    def list(path: typing.Union['Path', jpype.protocol.SupportsPath]) -> java.util.stream.Stream['Path']: ...
    @staticmethod
    def move(path: typing.Union['Path', jpype.protocol.SupportsPath], path2: typing.Union['Path', jpype.protocol.SupportsPath], copyOptionArray: typing.List[CopyOption]) -> 'Path': ...
    @typing.overload
    @staticmethod
    def newBufferedReader(path: typing.Union['Path', jpype.protocol.SupportsPath]) -> java.io.BufferedReader: ...
    @typing.overload
    @staticmethod
    def newBufferedReader(path: typing.Union['Path', jpype.protocol.SupportsPath], charset: java.nio.charset.Charset) -> java.io.BufferedReader: ...
    @typing.overload
    @staticmethod
    def newBufferedWriter(path: typing.Union['Path', jpype.protocol.SupportsPath], charset: java.nio.charset.Charset, openOptionArray: typing.List['OpenOption']) -> java.io.BufferedWriter: ...
    @typing.overload
    @staticmethod
    def newBufferedWriter(path: typing.Union['Path', jpype.protocol.SupportsPath], openOptionArray: typing.List['OpenOption']) -> java.io.BufferedWriter: ...
    @typing.overload
    @staticmethod
    def newByteChannel(path: typing.Union['Path', jpype.protocol.SupportsPath], openOptionArray: typing.List['OpenOption']) -> java.nio.channels.SeekableByteChannel: ...
    @typing.overload
    @staticmethod
    def newByteChannel(path: typing.Union['Path', jpype.protocol.SupportsPath], set: java.util.Set['OpenOption'], fileAttributeArray: typing.List[java.nio.file.attribute.FileAttribute[typing.Any]]) -> java.nio.channels.SeekableByteChannel: ...
    @typing.overload
    @staticmethod
    def newDirectoryStream(path: typing.Union['Path', jpype.protocol.SupportsPath]) -> DirectoryStream['Path']: ...
    @typing.overload
    @staticmethod
    def newDirectoryStream(path: typing.Union['Path', jpype.protocol.SupportsPath], string: str) -> DirectoryStream['Path']: ...
    @typing.overload
    @staticmethod
    def newDirectoryStream(path: typing.Union['Path', jpype.protocol.SupportsPath], filter: typing.Union[DirectoryStream.Filter['Path'], typing.Callable[['Path'], bool]]) -> DirectoryStream['Path']: ...
    @staticmethod
    def newInputStream(path: typing.Union['Path', jpype.protocol.SupportsPath], openOptionArray: typing.List['OpenOption']) -> java.io.InputStream: ...
    @staticmethod
    def newOutputStream(path: typing.Union['Path', jpype.protocol.SupportsPath], openOptionArray: typing.List['OpenOption']) -> java.io.OutputStream: ...
    @staticmethod
    def notExists(path: typing.Union['Path', jpype.protocol.SupportsPath], linkOptionArray: typing.List['LinkOption']) -> bool: ...
    @staticmethod
    def probeContentType(path: typing.Union['Path', jpype.protocol.SupportsPath]) -> str: ...
    @staticmethod
    def readAllBytes(path: typing.Union['Path', jpype.protocol.SupportsPath]) -> typing.List[int]: ...
    @typing.overload
    @staticmethod
    def readAllLines(path: typing.Union['Path', jpype.protocol.SupportsPath]) -> java.util.List[str]: ...
    @typing.overload
    @staticmethod
    def readAllLines(path: typing.Union['Path', jpype.protocol.SupportsPath], charset: java.nio.charset.Charset) -> java.util.List[str]: ...
    _readAttributes_0__A = typing.TypeVar('_readAttributes_0__A', bound=java.nio.file.attribute.BasicFileAttributes)  # <A>
    @typing.overload
    @staticmethod
    def readAttributes(path: typing.Union['Path', jpype.protocol.SupportsPath], class_: typing.Type[_readAttributes_0__A], linkOptionArray: typing.List['LinkOption']) -> _readAttributes_0__A: ...
    @typing.overload
    @staticmethod
    def readAttributes(path: typing.Union['Path', jpype.protocol.SupportsPath], string: str, linkOptionArray: typing.List['LinkOption']) -> java.util.Map[str, typing.Any]: ...
    @typing.overload
    @staticmethod
    def readString(path: typing.Union['Path', jpype.protocol.SupportsPath]) -> str: ...
    @typing.overload
    @staticmethod
    def readString(path: typing.Union['Path', jpype.protocol.SupportsPath], charset: java.nio.charset.Charset) -> str: ...
    @staticmethod
    def readSymbolicLink(path: typing.Union['Path', jpype.protocol.SupportsPath]) -> 'Path': ...
    @staticmethod
    def setAttribute(path: typing.Union['Path', jpype.protocol.SupportsPath], string: str, object: typing.Any, linkOptionArray: typing.List['LinkOption']) -> 'Path': ...
    @staticmethod
    def setLastModifiedTime(path: typing.Union['Path', jpype.protocol.SupportsPath], fileTime: java.nio.file.attribute.FileTime) -> 'Path': ...
    @staticmethod
    def setOwner(path: typing.Union['Path', jpype.protocol.SupportsPath], userPrincipal: java.nio.file.attribute.UserPrincipal) -> 'Path': ...
    @staticmethod
    def setPosixFilePermissions(path: typing.Union['Path', jpype.protocol.SupportsPath], set: java.util.Set[java.nio.file.attribute.PosixFilePermission]) -> 'Path': ...
    @staticmethod
    def size(path: typing.Union['Path', jpype.protocol.SupportsPath]) -> int: ...
    @typing.overload
    @staticmethod
    def walk(path: typing.Union['Path', jpype.protocol.SupportsPath], int: int, fileVisitOptionArray: typing.List[FileVisitOption]) -> java.util.stream.Stream['Path']: ...
    @typing.overload
    @staticmethod
    def walk(path: typing.Union['Path', jpype.protocol.SupportsPath], fileVisitOptionArray: typing.List[FileVisitOption]) -> java.util.stream.Stream['Path']: ...
    @typing.overload
    @staticmethod
    def walkFileTree(path: typing.Union['Path', jpype.protocol.SupportsPath], fileVisitor: FileVisitor['Path']) -> 'Path': ...
    @typing.overload
    @staticmethod
    def walkFileTree(path: typing.Union['Path', jpype.protocol.SupportsPath], set: java.util.Set[FileVisitOption], int: int, fileVisitor: FileVisitor['Path']) -> 'Path': ...
    @typing.overload
    @staticmethod
    def write(path: typing.Union['Path', jpype.protocol.SupportsPath], byteArray: typing.List[int], openOptionArray: typing.List['OpenOption']) -> 'Path': ...
    @typing.overload
    @staticmethod
    def write(path: typing.Union['Path', jpype.protocol.SupportsPath], iterable: typing.Union[java.lang.Iterable[java.lang.CharSequence], typing.Sequence[java.lang.CharSequence], typing.Set[java.lang.CharSequence]], charset: java.nio.charset.Charset, openOptionArray: typing.List['OpenOption']) -> 'Path': ...
    @typing.overload
    @staticmethod
    def write(path: typing.Union['Path', jpype.protocol.SupportsPath], iterable: typing.Union[java.lang.Iterable[java.lang.CharSequence], typing.Sequence[java.lang.CharSequence], typing.Set[java.lang.CharSequence]], openOptionArray: typing.List['OpenOption']) -> 'Path': ...
    @typing.overload
    @staticmethod
    def writeString(path: typing.Union['Path', jpype.protocol.SupportsPath], charSequence: typing.Union[java.lang.CharSequence, str], charset: java.nio.charset.Charset, openOptionArray: typing.List['OpenOption']) -> 'Path': ...
    @typing.overload
    @staticmethod
    def writeString(path: typing.Union['Path', jpype.protocol.SupportsPath], charSequence: typing.Union[java.lang.CharSequence, str], openOptionArray: typing.List['OpenOption']) -> 'Path': ...

class InvalidPathException(java.lang.IllegalArgumentException):
    @typing.overload
    def __init__(self, string: str, string2: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str, int: int): ...
    def getIndex(self) -> int: ...
    def getInput(self) -> str: ...
    def getMessage(self) -> str: ...
    def getReason(self) -> str: ...

class LinkPermission(java.security.BasicPermission):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str): ...

class OpenOption: ...

class PathMatcher:
    def matches(self, path: typing.Union['Path', jpype.protocol.SupportsPath]) -> bool: ...

class Paths:
    @typing.overload
    @staticmethod
    def get(string: str, stringArray: typing.List[str]) -> 'Path': ...
    @typing.overload
    @staticmethod
    def get(uRI: java.net.URI) -> 'Path': ...

class ProviderMismatchException(java.lang.IllegalArgumentException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class ProviderNotFoundException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class ReadOnlyFileSystemException(java.lang.UnsupportedOperationException):
    def __init__(self): ...

class StandardWatchEventKinds:
    OVERFLOW: typing.ClassVar['WatchEvent.Kind'] = ...
    ENTRY_CREATE: typing.ClassVar['WatchEvent.Kind'] = ...
    ENTRY_DELETE: typing.ClassVar['WatchEvent.Kind'] = ...
    ENTRY_MODIFY: typing.ClassVar['WatchEvent.Kind'] = ...

_WatchEvent__Kind__T = typing.TypeVar('_WatchEvent__Kind__T')  # <T>
_WatchEvent__T = typing.TypeVar('_WatchEvent__T')  # <T>
class WatchEvent(typing.Generic[_WatchEvent__T]):
    def context(self) -> _WatchEvent__T: ...
    def count(self) -> int: ...
    def kind(self) -> 'WatchEvent.Kind'[_WatchEvent__T]: ...
    class Kind(typing.Generic[_WatchEvent__Kind__T]):
        def name(self) -> str: ...
        def type(self) -> typing.Type[_WatchEvent__Kind__T]: ...
    class Modifier:
        def name(self) -> str: ...

class WatchKey:
    def cancel(self) -> None: ...
    def isValid(self) -> bool: ...
    def pollEvents(self) -> java.util.List[WatchEvent[typing.Any]]: ...
    def reset(self) -> bool: ...
    def watchable(self) -> 'Watchable': ...

class WatchService(java.io.Closeable):
    def close(self) -> None: ...
    @typing.overload
    def poll(self) -> WatchKey: ...
    @typing.overload
    def poll(self, long: int, timeUnit: java.util.concurrent.TimeUnit) -> WatchKey: ...
    def take(self) -> WatchKey: ...

class Watchable:
    @typing.overload
    def register(self, watchService: WatchService, kindArray: typing.List[WatchEvent.Kind[typing.Any]]) -> WatchKey: ...
    @typing.overload
    def register(self, watchService: WatchService, kindArray: typing.List[WatchEvent.Kind[typing.Any]], modifierArray: typing.List[WatchEvent.Modifier]) -> WatchKey: ...

class AccessDeniedException(FileSystemException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str, string3: str): ...

class AtomicMoveNotSupportedException(FileSystemException):
    def __init__(self, string: str, string2: str, string3: str): ...

class DirectoryNotEmptyException(FileSystemException):
    def __init__(self, string: str): ...

class FileAlreadyExistsException(FileSystemException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str, string3: str): ...

class FileSystemLoopException(FileSystemException):
    def __init__(self, string: str): ...

class LinkOption(java.lang.Enum['LinkOption'], OpenOption, CopyOption):
    NOFOLLOW_LINKS: typing.ClassVar['LinkOption'] = ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'LinkOption': ...
    @staticmethod
    def values() -> typing.List['LinkOption']: ...

class NoSuchFileException(FileSystemException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str, string3: str): ...

class NotDirectoryException(FileSystemException):
    def __init__(self, string: str): ...

class NotLinkException(FileSystemException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str, string3: str): ...

class Path(java.lang.Comparable['Path'], java.lang.Iterable['Path'], Watchable):
    def compareTo(self, path: typing.Union['Path', jpype.protocol.SupportsPath]) -> int: ...
    @typing.overload
    def endsWith(self, path: typing.Union['Path', jpype.protocol.SupportsPath]) -> bool: ...
    @typing.overload
    def endsWith(self, string: str) -> bool: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getFileName(self) -> 'Path': ...
    def getFileSystem(self) -> FileSystem: ...
    def getName(self, int: int) -> 'Path': ...
    def getNameCount(self) -> int: ...
    def getParent(self) -> 'Path': ...
    def getRoot(self) -> 'Path': ...
    def hashCode(self) -> int: ...
    def isAbsolute(self) -> bool: ...
    def iterator(self) -> java.util.Iterator['Path']: ...
    def normalize(self) -> 'Path': ...
    @typing.overload
    @staticmethod
    def of(string: str, stringArray: typing.List[str]) -> 'Path': ...
    @typing.overload
    @staticmethod
    def of(uRI: java.net.URI) -> 'Path': ...
    @typing.overload
    def register(self, watchService: WatchService, kindArray: typing.List[WatchEvent.Kind[typing.Any]], modifierArray: typing.List[WatchEvent.Modifier]) -> WatchKey: ...
    @typing.overload
    def register(self, watchService: WatchService, kindArray: typing.List[WatchEvent.Kind[typing.Any]]) -> WatchKey: ...
    def relativize(self, path: typing.Union['Path', jpype.protocol.SupportsPath]) -> 'Path': ...
    @typing.overload
    def resolve(self, path: typing.Union['Path', jpype.protocol.SupportsPath]) -> 'Path': ...
    @typing.overload
    def resolve(self, string: str) -> 'Path': ...
    @typing.overload
    def resolveSibling(self, string: str) -> 'Path': ...
    @typing.overload
    def resolveSibling(self, path: typing.Union['Path', jpype.protocol.SupportsPath]) -> 'Path': ...
    @typing.overload
    def startsWith(self, path: typing.Union['Path', jpype.protocol.SupportsPath]) -> bool: ...
    @typing.overload
    def startsWith(self, string: str) -> bool: ...
    def subpath(self, int: int, int2: int) -> 'Path': ...
    def toAbsolutePath(self) -> 'Path': ...
    def toFile(self) -> java.io.File: ...
    def toRealPath(self, linkOptionArray: typing.List[LinkOption]) -> 'Path': ...
    def toString(self) -> str: ...
    def toUri(self) -> java.net.URI: ...

_SecureDirectoryStream__T = typing.TypeVar('_SecureDirectoryStream__T')  # <T>
class SecureDirectoryStream(DirectoryStream[_SecureDirectoryStream__T], typing.Generic[_SecureDirectoryStream__T]):
    def deleteDirectory(self, t: _SecureDirectoryStream__T) -> None: ...
    def deleteFile(self, t: _SecureDirectoryStream__T) -> None: ...
    _getFileAttributeView_0__V = typing.TypeVar('_getFileAttributeView_0__V', bound=java.nio.file.attribute.FileAttributeView)  # <V>
    _getFileAttributeView_1__V = typing.TypeVar('_getFileAttributeView_1__V', bound=java.nio.file.attribute.FileAttributeView)  # <V>
    @typing.overload
    def getFileAttributeView(self, class_: typing.Type[_getFileAttributeView_0__V]) -> _getFileAttributeView_0__V: ...
    @typing.overload
    def getFileAttributeView(self, t: _SecureDirectoryStream__T, class_: typing.Type[_getFileAttributeView_1__V], linkOptionArray: typing.List[LinkOption]) -> _getFileAttributeView_1__V: ...
    def move(self, t: _SecureDirectoryStream__T, secureDirectoryStream: 'SecureDirectoryStream'[_SecureDirectoryStream__T], t2: _SecureDirectoryStream__T) -> None: ...
    def newByteChannel(self, t: _SecureDirectoryStream__T, set: java.util.Set[OpenOption], fileAttributeArray: typing.List[java.nio.file.attribute.FileAttribute[typing.Any]]) -> java.nio.channels.SeekableByteChannel: ...
    def newDirectoryStream(self, t: _SecureDirectoryStream__T, linkOptionArray: typing.List[LinkOption]) -> 'SecureDirectoryStream'[_SecureDirectoryStream__T]: ...

_SimpleFileVisitor__T = typing.TypeVar('_SimpleFileVisitor__T')  # <T>
class SimpleFileVisitor(FileVisitor[_SimpleFileVisitor__T], typing.Generic[_SimpleFileVisitor__T]):
    def postVisitDirectory(self, t: _SimpleFileVisitor__T, iOException: java.io.IOException) -> FileVisitResult: ...
    def preVisitDirectory(self, t: _SimpleFileVisitor__T, basicFileAttributes: java.nio.file.attribute.BasicFileAttributes) -> FileVisitResult: ...
    def visitFile(self, t: _SimpleFileVisitor__T, basicFileAttributes: java.nio.file.attribute.BasicFileAttributes) -> FileVisitResult: ...
    def visitFileFailed(self, t: _SimpleFileVisitor__T, iOException: java.io.IOException) -> FileVisitResult: ...

class StandardCopyOption(java.lang.Enum['StandardCopyOption'], CopyOption):
    REPLACE_EXISTING: typing.ClassVar['StandardCopyOption'] = ...
    COPY_ATTRIBUTES: typing.ClassVar['StandardCopyOption'] = ...
    ATOMIC_MOVE: typing.ClassVar['StandardCopyOption'] = ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'StandardCopyOption': ...
    @staticmethod
    def values() -> typing.List['StandardCopyOption']: ...

class StandardOpenOption(java.lang.Enum['StandardOpenOption'], OpenOption):
    READ: typing.ClassVar['StandardOpenOption'] = ...
    WRITE: typing.ClassVar['StandardOpenOption'] = ...
    APPEND: typing.ClassVar['StandardOpenOption'] = ...
    TRUNCATE_EXISTING: typing.ClassVar['StandardOpenOption'] = ...
    CREATE: typing.ClassVar['StandardOpenOption'] = ...
    CREATE_NEW: typing.ClassVar['StandardOpenOption'] = ...
    DELETE_ON_CLOSE: typing.ClassVar['StandardOpenOption'] = ...
    SPARSE: typing.ClassVar['StandardOpenOption'] = ...
    SYNC: typing.ClassVar['StandardOpenOption'] = ...
    DSYNC: typing.ClassVar['StandardOpenOption'] = ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'StandardOpenOption': ...
    @staticmethod
    def values() -> typing.List['StandardOpenOption']: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.nio.file")``.

    AccessDeniedException: typing.Type[AccessDeniedException]
    AccessMode: typing.Type[AccessMode]
    AtomicMoveNotSupportedException: typing.Type[AtomicMoveNotSupportedException]
    ClosedDirectoryStreamException: typing.Type[ClosedDirectoryStreamException]
    ClosedFileSystemException: typing.Type[ClosedFileSystemException]
    ClosedWatchServiceException: typing.Type[ClosedWatchServiceException]
    CopyOption: typing.Type[CopyOption]
    DirectoryIteratorException: typing.Type[DirectoryIteratorException]
    DirectoryNotEmptyException: typing.Type[DirectoryNotEmptyException]
    DirectoryStream: typing.Type[DirectoryStream]
    FileAlreadyExistsException: typing.Type[FileAlreadyExistsException]
    FileStore: typing.Type[FileStore]
    FileSystem: typing.Type[FileSystem]
    FileSystemAlreadyExistsException: typing.Type[FileSystemAlreadyExistsException]
    FileSystemException: typing.Type[FileSystemException]
    FileSystemLoopException: typing.Type[FileSystemLoopException]
    FileSystemNotFoundException: typing.Type[FileSystemNotFoundException]
    FileSystems: typing.Type[FileSystems]
    FileVisitOption: typing.Type[FileVisitOption]
    FileVisitResult: typing.Type[FileVisitResult]
    FileVisitor: typing.Type[FileVisitor]
    Files: typing.Type[Files]
    InvalidPathException: typing.Type[InvalidPathException]
    LinkOption: typing.Type[LinkOption]
    LinkPermission: typing.Type[LinkPermission]
    NoSuchFileException: typing.Type[NoSuchFileException]
    NotDirectoryException: typing.Type[NotDirectoryException]
    NotLinkException: typing.Type[NotLinkException]
    OpenOption: typing.Type[OpenOption]
    Path: typing.Type[Path]
    PathMatcher: typing.Type[PathMatcher]
    Paths: typing.Type[Paths]
    ProviderMismatchException: typing.Type[ProviderMismatchException]
    ProviderNotFoundException: typing.Type[ProviderNotFoundException]
    ReadOnlyFileSystemException: typing.Type[ReadOnlyFileSystemException]
    SecureDirectoryStream: typing.Type[SecureDirectoryStream]
    SimpleFileVisitor: typing.Type[SimpleFileVisitor]
    StandardCopyOption: typing.Type[StandardCopyOption]
    StandardOpenOption: typing.Type[StandardOpenOption]
    StandardWatchEventKinds: typing.Type[StandardWatchEventKinds]
    WatchEvent: typing.Type[WatchEvent]
    WatchKey: typing.Type[WatchKey]
    WatchService: typing.Type[WatchService]
    Watchable: typing.Type[Watchable]
    attribute: java.nio.file.attribute.__module_protocol__
    spi: java.nio.file.spi.__module_protocol__
